# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .provider import *

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_oci.adm as __adm
    adm = __adm
    import pulumi_oci.aianomalydetection as __aianomalydetection
    aianomalydetection = __aianomalydetection
    import pulumi_oci.aivision as __aivision
    aivision = __aivision
    import pulumi_oci.analytics as __analytics
    analytics = __analytics
    import pulumi_oci.announcementsservice as __announcementsservice
    announcementsservice = __announcementsservice
    import pulumi_oci.apigateway as __apigateway
    apigateway = __apigateway
    import pulumi_oci.apm as __apm
    apm = __apm
    import pulumi_oci.apmconfig as __apmconfig
    apmconfig = __apmconfig
    import pulumi_oci.apmsynthetics as __apmsynthetics
    apmsynthetics = __apmsynthetics
    import pulumi_oci.apmtraces as __apmtraces
    apmtraces = __apmtraces
    import pulumi_oci.appmgmtcontrol as __appmgmtcontrol
    appmgmtcontrol = __appmgmtcontrol
    import pulumi_oci.artifacts as __artifacts
    artifacts = __artifacts
    import pulumi_oci.audit as __audit
    audit = __audit
    import pulumi_oci.autoscaling as __autoscaling
    autoscaling = __autoscaling
    import pulumi_oci.bastion as __bastion
    bastion = __bastion
    import pulumi_oci.bigdataservice as __bigdataservice
    bigdataservice = __bigdataservice
    import pulumi_oci.blockchain as __blockchain
    blockchain = __blockchain
    import pulumi_oci.budget as __budget
    budget = __budget
    import pulumi_oci.certificatesmanagement as __certificatesmanagement
    certificatesmanagement = __certificatesmanagement
    import pulumi_oci.cloudbridge as __cloudbridge
    cloudbridge = __cloudbridge
    import pulumi_oci.cloudguard as __cloudguard
    cloudguard = __cloudguard
    import pulumi_oci.cloudmigrations as __cloudmigrations
    cloudmigrations = __cloudmigrations
    import pulumi_oci.computeinstanceagent as __computeinstanceagent
    computeinstanceagent = __computeinstanceagent
    import pulumi_oci.config as __config
    config = __config
    import pulumi_oci.containerengine as __containerengine
    containerengine = __containerengine
    import pulumi_oci.containerinstances as __containerinstances
    containerinstances = __containerinstances
    import pulumi_oci.core as __core
    core = __core
    import pulumi_oci.database as __database
    database = __database
    import pulumi_oci.databasemanagement as __databasemanagement
    databasemanagement = __databasemanagement
    import pulumi_oci.databasemigration as __databasemigration
    databasemigration = __databasemigration
    import pulumi_oci.databasetools as __databasetools
    databasetools = __databasetools
    import pulumi_oci.datacatalog as __datacatalog
    datacatalog = __datacatalog
    import pulumi_oci.dataflow as __dataflow
    dataflow = __dataflow
    import pulumi_oci.dataintegration as __dataintegration
    dataintegration = __dataintegration
    import pulumi_oci.datalabellingservice as __datalabellingservice
    datalabellingservice = __datalabellingservice
    import pulumi_oci.datasafe as __datasafe
    datasafe = __datasafe
    import pulumi_oci.datascience as __datascience
    datascience = __datascience
    import pulumi_oci.devops as __devops
    devops = __devops
    import pulumi_oci.disasterrecovery as __disasterrecovery
    disasterrecovery = __disasterrecovery
    import pulumi_oci.dns as __dns
    dns = __dns
    import pulumi_oci.email as __email
    email = __email
    import pulumi_oci.emwarehouse as __emwarehouse
    emwarehouse = __emwarehouse
    import pulumi_oci.events as __events
    events = __events
    import pulumi_oci.filestorage as __filestorage
    filestorage = __filestorage
    import pulumi_oci.functions as __functions
    functions = __functions
    import pulumi_oci.fusionapps as __fusionapps
    fusionapps = __fusionapps
    import pulumi_oci.genericartifactscontent as __genericartifactscontent
    genericartifactscontent = __genericartifactscontent
    import pulumi_oci.goldengate as __goldengate
    goldengate = __goldengate
    import pulumi_oci.healthchecks as __healthchecks
    healthchecks = __healthchecks
    import pulumi_oci.identity as __identity
    identity = __identity
    import pulumi_oci.identitydataplane as __identitydataplane
    identitydataplane = __identitydataplane
    import pulumi_oci.integration as __integration
    integration = __integration
    import pulumi_oci.jms as __jms
    jms = __jms
    import pulumi_oci.kms as __kms
    kms = __kms
    import pulumi_oci.licensemanager as __licensemanager
    licensemanager = __licensemanager
    import pulumi_oci.limits as __limits
    limits = __limits
    import pulumi_oci.loadbalancer as __loadbalancer
    loadbalancer = __loadbalancer
    import pulumi_oci.loganalytics as __loganalytics
    loganalytics = __loganalytics
    import pulumi_oci.logging as __logging
    logging = __logging
    import pulumi_oci.managementagent as __managementagent
    managementagent = __managementagent
    import pulumi_oci.managementdashboard as __managementdashboard
    managementdashboard = __managementdashboard
    import pulumi_oci.marketplace as __marketplace
    marketplace = __marketplace
    import pulumi_oci.mediaservices as __mediaservices
    mediaservices = __mediaservices
    import pulumi_oci.meteringcomputation as __meteringcomputation
    meteringcomputation = __meteringcomputation
    import pulumi_oci.monitoring as __monitoring
    monitoring = __monitoring
    import pulumi_oci.mysql as __mysql
    mysql = __mysql
    import pulumi_oci.networkfirewall as __networkfirewall
    networkfirewall = __networkfirewall
    import pulumi_oci.networkloadbalancer as __networkloadbalancer
    networkloadbalancer = __networkloadbalancer
    import pulumi_oci.nosql as __nosql
    nosql = __nosql
    import pulumi_oci.objectstorage as __objectstorage
    objectstorage = __objectstorage
    import pulumi_oci.oce as __oce
    oce = __oce
    import pulumi_oci.ocvp as __ocvp
    ocvp = __ocvp
    import pulumi_oci.oda as __oda
    oda = __oda
    import pulumi_oci.onesubsription as __onesubsription
    onesubsription = __onesubsription
    import pulumi_oci.ons as __ons
    ons = __ons
    import pulumi_oci.opa as __opa
    opa = __opa
    import pulumi_oci.opensearch as __opensearch
    opensearch = __opensearch
    import pulumi_oci.operatoraccesscontrol as __operatoraccesscontrol
    operatoraccesscontrol = __operatoraccesscontrol
    import pulumi_oci.opsi as __opsi
    opsi = __opsi
    import pulumi_oci.optimizer as __optimizer
    optimizer = __optimizer
    import pulumi_oci.osmanagement as __osmanagement
    osmanagement = __osmanagement
    import pulumi_oci.ospgateway as __ospgateway
    ospgateway = __ospgateway
    import pulumi_oci.osubbillingschedule as __osubbillingschedule
    osubbillingschedule = __osubbillingschedule
    import pulumi_oci.osuborganizationsubscription as __osuborganizationsubscription
    osuborganizationsubscription = __osuborganizationsubscription
    import pulumi_oci.osubsubscription as __osubsubscription
    osubsubscription = __osubsubscription
    import pulumi_oci.osubusage as __osubusage
    osubusage = __osubusage
    import pulumi_oci.queue as __queue
    queue = __queue
    import pulumi_oci.recoverymod as __recoverymod
    recoverymod = __recoverymod
    import pulumi_oci.resourcemanager as __resourcemanager
    resourcemanager = __resourcemanager
    import pulumi_oci.sch as __sch
    sch = __sch
    import pulumi_oci.secrets as __secrets
    secrets = __secrets
    import pulumi_oci.servicecatalog as __servicecatalog
    servicecatalog = __servicecatalog
    import pulumi_oci.servicemanagerproxy as __servicemanagerproxy
    servicemanagerproxy = __servicemanagerproxy
    import pulumi_oci.servicemesh as __servicemesh
    servicemesh = __servicemesh
    import pulumi_oci.stackmonitoring as __stackmonitoring
    stackmonitoring = __stackmonitoring
    import pulumi_oci.streaming as __streaming
    streaming = __streaming
    import pulumi_oci.usageproxy as __usageproxy
    usageproxy = __usageproxy
    import pulumi_oci.vault as __vault
    vault = __vault
    import pulumi_oci.vbs as __vbs
    vbs = __vbs
    import pulumi_oci.visualbuilder as __visualbuilder
    visualbuilder = __visualbuilder
    import pulumi_oci.vnmonitoring as __vnmonitoring
    vnmonitoring = __vnmonitoring
    import pulumi_oci.vulnerabilityscanning as __vulnerabilityscanning
    vulnerabilityscanning = __vulnerabilityscanning
    import pulumi_oci.waa as __waa
    waa = __waa
    import pulumi_oci.waas as __waas
    waas = __waas
    import pulumi_oci.waf as __waf
    waf = __waf
else:
    adm = _utilities.lazy_import('pulumi_oci.adm')
    aianomalydetection = _utilities.lazy_import('pulumi_oci.aianomalydetection')
    aivision = _utilities.lazy_import('pulumi_oci.aivision')
    analytics = _utilities.lazy_import('pulumi_oci.analytics')
    announcementsservice = _utilities.lazy_import('pulumi_oci.announcementsservice')
    apigateway = _utilities.lazy_import('pulumi_oci.apigateway')
    apm = _utilities.lazy_import('pulumi_oci.apm')
    apmconfig = _utilities.lazy_import('pulumi_oci.apmconfig')
    apmsynthetics = _utilities.lazy_import('pulumi_oci.apmsynthetics')
    apmtraces = _utilities.lazy_import('pulumi_oci.apmtraces')
    appmgmtcontrol = _utilities.lazy_import('pulumi_oci.appmgmtcontrol')
    artifacts = _utilities.lazy_import('pulumi_oci.artifacts')
    audit = _utilities.lazy_import('pulumi_oci.audit')
    autoscaling = _utilities.lazy_import('pulumi_oci.autoscaling')
    bastion = _utilities.lazy_import('pulumi_oci.bastion')
    bigdataservice = _utilities.lazy_import('pulumi_oci.bigdataservice')
    blockchain = _utilities.lazy_import('pulumi_oci.blockchain')
    budget = _utilities.lazy_import('pulumi_oci.budget')
    certificatesmanagement = _utilities.lazy_import('pulumi_oci.certificatesmanagement')
    cloudbridge = _utilities.lazy_import('pulumi_oci.cloudbridge')
    cloudguard = _utilities.lazy_import('pulumi_oci.cloudguard')
    cloudmigrations = _utilities.lazy_import('pulumi_oci.cloudmigrations')
    computeinstanceagent = _utilities.lazy_import('pulumi_oci.computeinstanceagent')
    config = _utilities.lazy_import('pulumi_oci.config')
    containerengine = _utilities.lazy_import('pulumi_oci.containerengine')
    containerinstances = _utilities.lazy_import('pulumi_oci.containerinstances')
    core = _utilities.lazy_import('pulumi_oci.core')
    database = _utilities.lazy_import('pulumi_oci.database')
    databasemanagement = _utilities.lazy_import('pulumi_oci.databasemanagement')
    databasemigration = _utilities.lazy_import('pulumi_oci.databasemigration')
    databasetools = _utilities.lazy_import('pulumi_oci.databasetools')
    datacatalog = _utilities.lazy_import('pulumi_oci.datacatalog')
    dataflow = _utilities.lazy_import('pulumi_oci.dataflow')
    dataintegration = _utilities.lazy_import('pulumi_oci.dataintegration')
    datalabellingservice = _utilities.lazy_import('pulumi_oci.datalabellingservice')
    datasafe = _utilities.lazy_import('pulumi_oci.datasafe')
    datascience = _utilities.lazy_import('pulumi_oci.datascience')
    devops = _utilities.lazy_import('pulumi_oci.devops')
    disasterrecovery = _utilities.lazy_import('pulumi_oci.disasterrecovery')
    dns = _utilities.lazy_import('pulumi_oci.dns')
    email = _utilities.lazy_import('pulumi_oci.email')
    emwarehouse = _utilities.lazy_import('pulumi_oci.emwarehouse')
    events = _utilities.lazy_import('pulumi_oci.events')
    filestorage = _utilities.lazy_import('pulumi_oci.filestorage')
    functions = _utilities.lazy_import('pulumi_oci.functions')
    fusionapps = _utilities.lazy_import('pulumi_oci.fusionapps')
    genericartifactscontent = _utilities.lazy_import('pulumi_oci.genericartifactscontent')
    goldengate = _utilities.lazy_import('pulumi_oci.goldengate')
    healthchecks = _utilities.lazy_import('pulumi_oci.healthchecks')
    identity = _utilities.lazy_import('pulumi_oci.identity')
    identitydataplane = _utilities.lazy_import('pulumi_oci.identitydataplane')
    integration = _utilities.lazy_import('pulumi_oci.integration')
    jms = _utilities.lazy_import('pulumi_oci.jms')
    kms = _utilities.lazy_import('pulumi_oci.kms')
    licensemanager = _utilities.lazy_import('pulumi_oci.licensemanager')
    limits = _utilities.lazy_import('pulumi_oci.limits')
    loadbalancer = _utilities.lazy_import('pulumi_oci.loadbalancer')
    loganalytics = _utilities.lazy_import('pulumi_oci.loganalytics')
    logging = _utilities.lazy_import('pulumi_oci.logging')
    managementagent = _utilities.lazy_import('pulumi_oci.managementagent')
    managementdashboard = _utilities.lazy_import('pulumi_oci.managementdashboard')
    marketplace = _utilities.lazy_import('pulumi_oci.marketplace')
    mediaservices = _utilities.lazy_import('pulumi_oci.mediaservices')
    meteringcomputation = _utilities.lazy_import('pulumi_oci.meteringcomputation')
    monitoring = _utilities.lazy_import('pulumi_oci.monitoring')
    mysql = _utilities.lazy_import('pulumi_oci.mysql')
    networkfirewall = _utilities.lazy_import('pulumi_oci.networkfirewall')
    networkloadbalancer = _utilities.lazy_import('pulumi_oci.networkloadbalancer')
    nosql = _utilities.lazy_import('pulumi_oci.nosql')
    objectstorage = _utilities.lazy_import('pulumi_oci.objectstorage')
    oce = _utilities.lazy_import('pulumi_oci.oce')
    ocvp = _utilities.lazy_import('pulumi_oci.ocvp')
    oda = _utilities.lazy_import('pulumi_oci.oda')
    onesubsription = _utilities.lazy_import('pulumi_oci.onesubsription')
    ons = _utilities.lazy_import('pulumi_oci.ons')
    opa = _utilities.lazy_import('pulumi_oci.opa')
    opensearch = _utilities.lazy_import('pulumi_oci.opensearch')
    operatoraccesscontrol = _utilities.lazy_import('pulumi_oci.operatoraccesscontrol')
    opsi = _utilities.lazy_import('pulumi_oci.opsi')
    optimizer = _utilities.lazy_import('pulumi_oci.optimizer')
    osmanagement = _utilities.lazy_import('pulumi_oci.osmanagement')
    ospgateway = _utilities.lazy_import('pulumi_oci.ospgateway')
    osubbillingschedule = _utilities.lazy_import('pulumi_oci.osubbillingschedule')
    osuborganizationsubscription = _utilities.lazy_import('pulumi_oci.osuborganizationsubscription')
    osubsubscription = _utilities.lazy_import('pulumi_oci.osubsubscription')
    osubusage = _utilities.lazy_import('pulumi_oci.osubusage')
    queue = _utilities.lazy_import('pulumi_oci.queue')
    recoverymod = _utilities.lazy_import('pulumi_oci.recoverymod')
    resourcemanager = _utilities.lazy_import('pulumi_oci.resourcemanager')
    sch = _utilities.lazy_import('pulumi_oci.sch')
    secrets = _utilities.lazy_import('pulumi_oci.secrets')
    servicecatalog = _utilities.lazy_import('pulumi_oci.servicecatalog')
    servicemanagerproxy = _utilities.lazy_import('pulumi_oci.servicemanagerproxy')
    servicemesh = _utilities.lazy_import('pulumi_oci.servicemesh')
    stackmonitoring = _utilities.lazy_import('pulumi_oci.stackmonitoring')
    streaming = _utilities.lazy_import('pulumi_oci.streaming')
    usageproxy = _utilities.lazy_import('pulumi_oci.usageproxy')
    vault = _utilities.lazy_import('pulumi_oci.vault')
    vbs = _utilities.lazy_import('pulumi_oci.vbs')
    visualbuilder = _utilities.lazy_import('pulumi_oci.visualbuilder')
    vnmonitoring = _utilities.lazy_import('pulumi_oci.vnmonitoring')
    vulnerabilityscanning = _utilities.lazy_import('pulumi_oci.vulnerabilityscanning')
    waa = _utilities.lazy_import('pulumi_oci.waa')
    waas = _utilities.lazy_import('pulumi_oci.waas')
    waf = _utilities.lazy_import('pulumi_oci.waf')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "oci",
  "mod": "Adm/knowledgeBase",
  "fqn": "pulumi_oci.adm",
  "classes": {
   "oci:Adm/knowledgeBase:KnowledgeBase": "KnowledgeBase"
  }
 },
 {
  "pkg": "oci",
  "mod": "Adm/vulnerabilityAudit",
  "fqn": "pulumi_oci.adm",
  "classes": {
   "oci:Adm/vulnerabilityAudit:VulnerabilityAudit": "VulnerabilityAudit"
  }
 },
 {
  "pkg": "oci",
  "mod": "AiAnomalyDetection/aiPrivateEndpoint",
  "fqn": "pulumi_oci.aianomalydetection",
  "classes": {
   "oci:AiAnomalyDetection/aiPrivateEndpoint:AiPrivateEndpoint": "AiPrivateEndpoint"
  }
 },
 {
  "pkg": "oci",
  "mod": "AiAnomalyDetection/dataAsset",
  "fqn": "pulumi_oci.aianomalydetection",
  "classes": {
   "oci:AiAnomalyDetection/dataAsset:DataAsset": "DataAsset"
  }
 },
 {
  "pkg": "oci",
  "mod": "AiAnomalyDetection/detectAnomalyJob",
  "fqn": "pulumi_oci.aianomalydetection",
  "classes": {
   "oci:AiAnomalyDetection/detectAnomalyJob:DetectAnomalyJob": "DetectAnomalyJob"
  }
 },
 {
  "pkg": "oci",
  "mod": "AiAnomalyDetection/model",
  "fqn": "pulumi_oci.aianomalydetection",
  "classes": {
   "oci:AiAnomalyDetection/model:Model": "Model"
  }
 },
 {
  "pkg": "oci",
  "mod": "AiAnomalyDetection/project",
  "fqn": "pulumi_oci.aianomalydetection",
  "classes": {
   "oci:AiAnomalyDetection/project:Project": "Project"
  }
 },
 {
  "pkg": "oci",
  "mod": "AiVision/model",
  "fqn": "pulumi_oci.aivision",
  "classes": {
   "oci:AiVision/model:Model": "Model"
  }
 },
 {
  "pkg": "oci",
  "mod": "AiVision/project",
  "fqn": "pulumi_oci.aivision",
  "classes": {
   "oci:AiVision/project:Project": "Project"
  }
 },
 {
  "pkg": "oci",
  "mod": "Analytics/analyticsInstance",
  "fqn": "pulumi_oci.analytics",
  "classes": {
   "oci:Analytics/analyticsInstance:AnalyticsInstance": "AnalyticsInstance"
  }
 },
 {
  "pkg": "oci",
  "mod": "Analytics/analyticsInstancePrivateAccessChannel",
  "fqn": "pulumi_oci.analytics",
  "classes": {
   "oci:Analytics/analyticsInstancePrivateAccessChannel:AnalyticsInstancePrivateAccessChannel": "AnalyticsInstancePrivateAccessChannel"
  }
 },
 {
  "pkg": "oci",
  "mod": "Analytics/analyticsInstanceVanityUrl",
  "fqn": "pulumi_oci.analytics",
  "classes": {
   "oci:Analytics/analyticsInstanceVanityUrl:AnalyticsInstanceVanityUrl": "AnalyticsInstanceVanityUrl"
  }
 },
 {
  "pkg": "oci",
  "mod": "AnnouncementsService/announcementSubscription",
  "fqn": "pulumi_oci.announcementsservice",
  "classes": {
   "oci:AnnouncementsService/announcementSubscription:AnnouncementSubscription": "AnnouncementSubscription"
  }
 },
 {
  "pkg": "oci",
  "mod": "AnnouncementsService/announcementSubscriptionsActionsChangeCompartment",
  "fqn": "pulumi_oci.announcementsservice",
  "classes": {
   "oci:AnnouncementsService/announcementSubscriptionsActionsChangeCompartment:AnnouncementSubscriptionsActionsChangeCompartment": "AnnouncementSubscriptionsActionsChangeCompartment"
  }
 },
 {
  "pkg": "oci",
  "mod": "AnnouncementsService/announcementSubscriptionsFilterGroup",
  "fqn": "pulumi_oci.announcementsservice",
  "classes": {
   "oci:AnnouncementsService/announcementSubscriptionsFilterGroup:AnnouncementSubscriptionsFilterGroup": "AnnouncementSubscriptionsFilterGroup"
  }
 },
 {
  "pkg": "oci",
  "mod": "ApiGateway/api",
  "fqn": "pulumi_oci.apigateway",
  "classes": {
   "oci:ApiGateway/api:Api": "Api"
  }
 },
 {
  "pkg": "oci",
  "mod": "ApiGateway/certificate",
  "fqn": "pulumi_oci.apigateway",
  "classes": {
   "oci:ApiGateway/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "oci",
  "mod": "ApiGateway/deployment",
  "fqn": "pulumi_oci.apigateway",
  "classes": {
   "oci:ApiGateway/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "oci",
  "mod": "ApiGateway/gateway",
  "fqn": "pulumi_oci.apigateway",
  "classes": {
   "oci:ApiGateway/gateway:Gateway": "Gateway"
  }
 },
 {
  "pkg": "oci",
  "mod": "ApiGateway/subscriber",
  "fqn": "pulumi_oci.apigateway",
  "classes": {
   "oci:ApiGateway/subscriber:Subscriber": "Subscriber"
  }
 },
 {
  "pkg": "oci",
  "mod": "ApiGateway/usagePlan",
  "fqn": "pulumi_oci.apigateway",
  "classes": {
   "oci:ApiGateway/usagePlan:UsagePlan": "UsagePlan"
  }
 },
 {
  "pkg": "oci",
  "mod": "Apm/apmDomain",
  "fqn": "pulumi_oci.apm",
  "classes": {
   "oci:Apm/apmDomain:ApmDomain": "ApmDomain"
  }
 },
 {
  "pkg": "oci",
  "mod": "ApmConfig/config",
  "fqn": "pulumi_oci.apmconfig",
  "classes": {
   "oci:ApmConfig/config:Config": "Config"
  }
 },
 {
  "pkg": "oci",
  "mod": "ApmSynthetics/config",
  "fqn": "pulumi_oci.apmsynthetics",
  "classes": {
   "oci:ApmSynthetics/config:Config": "Config"
  }
 },
 {
  "pkg": "oci",
  "mod": "ApmSynthetics/dedicatedVantagePoint",
  "fqn": "pulumi_oci.apmsynthetics",
  "classes": {
   "oci:ApmSynthetics/dedicatedVantagePoint:DedicatedVantagePoint": "DedicatedVantagePoint"
  }
 },
 {
  "pkg": "oci",
  "mod": "ApmSynthetics/script",
  "fqn": "pulumi_oci.apmsynthetics",
  "classes": {
   "oci:ApmSynthetics/script:Script": "Script"
  }
 },
 {
  "pkg": "oci",
  "mod": "AppMgmtControl/monitorPluginManagement",
  "fqn": "pulumi_oci.appmgmtcontrol",
  "classes": {
   "oci:AppMgmtControl/monitorPluginManagement:MonitorPluginManagement": "MonitorPluginManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Artifacts/containerConfiguration",
  "fqn": "pulumi_oci.artifacts",
  "classes": {
   "oci:Artifacts/containerConfiguration:ContainerConfiguration": "ContainerConfiguration"
  }
 },
 {
  "pkg": "oci",
  "mod": "Artifacts/containerImageSignature",
  "fqn": "pulumi_oci.artifacts",
  "classes": {
   "oci:Artifacts/containerImageSignature:ContainerImageSignature": "ContainerImageSignature"
  }
 },
 {
  "pkg": "oci",
  "mod": "Artifacts/containerRepository",
  "fqn": "pulumi_oci.artifacts",
  "classes": {
   "oci:Artifacts/containerRepository:ContainerRepository": "ContainerRepository"
  }
 },
 {
  "pkg": "oci",
  "mod": "Artifacts/genericArtifact",
  "fqn": "pulumi_oci.artifacts",
  "classes": {
   "oci:Artifacts/genericArtifact:GenericArtifact": "GenericArtifact"
  }
 },
 {
  "pkg": "oci",
  "mod": "Artifacts/repository",
  "fqn": "pulumi_oci.artifacts",
  "classes": {
   "oci:Artifacts/repository:Repository": "Repository"
  }
 },
 {
  "pkg": "oci",
  "mod": "Audit/configuration",
  "fqn": "pulumi_oci.audit",
  "classes": {
   "oci:Audit/configuration:Configuration": "Configuration"
  }
 },
 {
  "pkg": "oci",
  "mod": "Autoscaling/autoScalingConfiguration",
  "fqn": "pulumi_oci.autoscaling",
  "classes": {
   "oci:Autoscaling/autoScalingConfiguration:AutoScalingConfiguration": "AutoScalingConfiguration"
  }
 },
 {
  "pkg": "oci",
  "mod": "Bastion/bastion",
  "fqn": "pulumi_oci.bastion",
  "classes": {
   "oci:Bastion/bastion:Bastion": "Bastion"
  }
 },
 {
  "pkg": "oci",
  "mod": "Bastion/session",
  "fqn": "pulumi_oci.bastion",
  "classes": {
   "oci:Bastion/session:Session": "Session"
  }
 },
 {
  "pkg": "oci",
  "mod": "BigDataService/autoScalingConfiguration",
  "fqn": "pulumi_oci.bigdataservice",
  "classes": {
   "oci:BigDataService/autoScalingConfiguration:AutoScalingConfiguration": "AutoScalingConfiguration"
  }
 },
 {
  "pkg": "oci",
  "mod": "BigDataService/bdsInstance",
  "fqn": "pulumi_oci.bigdataservice",
  "classes": {
   "oci:BigDataService/bdsInstance:BdsInstance": "BdsInstance"
  }
 },
 {
  "pkg": "oci",
  "mod": "BigDataService/bdsInstanceApiKey",
  "fqn": "pulumi_oci.bigdataservice",
  "classes": {
   "oci:BigDataService/bdsInstanceApiKey:BdsInstanceApiKey": "BdsInstanceApiKey"
  }
 },
 {
  "pkg": "oci",
  "mod": "BigDataService/bdsInstanceMetastoreConfig",
  "fqn": "pulumi_oci.bigdataservice",
  "classes": {
   "oci:BigDataService/bdsInstanceMetastoreConfig:BdsInstanceMetastoreConfig": "BdsInstanceMetastoreConfig"
  }
 },
 {
  "pkg": "oci",
  "mod": "BigDataService/bdsInstancePatchAction",
  "fqn": "pulumi_oci.bigdataservice",
  "classes": {
   "oci:BigDataService/bdsInstancePatchAction:BdsInstancePatchAction": "BdsInstancePatchAction"
  }
 },
 {
  "pkg": "oci",
  "mod": "Blockchain/blockchainPlatform",
  "fqn": "pulumi_oci.blockchain",
  "classes": {
   "oci:Blockchain/blockchainPlatform:BlockchainPlatform": "BlockchainPlatform"
  }
 },
 {
  "pkg": "oci",
  "mod": "Blockchain/osn",
  "fqn": "pulumi_oci.blockchain",
  "classes": {
   "oci:Blockchain/osn:Osn": "Osn"
  }
 },
 {
  "pkg": "oci",
  "mod": "Blockchain/peer",
  "fqn": "pulumi_oci.blockchain",
  "classes": {
   "oci:Blockchain/peer:Peer": "Peer"
  }
 },
 {
  "pkg": "oci",
  "mod": "Budget/budget",
  "fqn": "pulumi_oci.budget",
  "classes": {
   "oci:Budget/budget:Budget": "Budget"
  }
 },
 {
  "pkg": "oci",
  "mod": "Budget/rule",
  "fqn": "pulumi_oci.budget",
  "classes": {
   "oci:Budget/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "oci",
  "mod": "CertificatesManagement/caBundle",
  "fqn": "pulumi_oci.certificatesmanagement",
  "classes": {
   "oci:CertificatesManagement/caBundle:CaBundle": "CaBundle"
  }
 },
 {
  "pkg": "oci",
  "mod": "CertificatesManagement/certificate",
  "fqn": "pulumi_oci.certificatesmanagement",
  "classes": {
   "oci:CertificatesManagement/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "oci",
  "mod": "CertificatesManagement/certificateAuthority",
  "fqn": "pulumi_oci.certificatesmanagement",
  "classes": {
   "oci:CertificatesManagement/certificateAuthority:CertificateAuthority": "CertificateAuthority"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudBridge/agent",
  "fqn": "pulumi_oci.cloudbridge",
  "classes": {
   "oci:CloudBridge/agent:Agent": "Agent"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudBridge/agentDependency",
  "fqn": "pulumi_oci.cloudbridge",
  "classes": {
   "oci:CloudBridge/agentDependency:AgentDependency": "AgentDependency"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudBridge/agentPlugin",
  "fqn": "pulumi_oci.cloudbridge",
  "classes": {
   "oci:CloudBridge/agentPlugin:AgentPlugin": "AgentPlugin"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudBridge/asset",
  "fqn": "pulumi_oci.cloudbridge",
  "classes": {
   "oci:CloudBridge/asset:Asset": "Asset"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudBridge/assetSource",
  "fqn": "pulumi_oci.cloudbridge",
  "classes": {
   "oci:CloudBridge/assetSource:AssetSource": "AssetSource"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudBridge/discoverySchedule",
  "fqn": "pulumi_oci.cloudbridge",
  "classes": {
   "oci:CloudBridge/discoverySchedule:DiscoverySchedule": "DiscoverySchedule"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudBridge/environment",
  "fqn": "pulumi_oci.cloudbridge",
  "classes": {
   "oci:CloudBridge/environment:Environment": "Environment"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudBridge/inventory",
  "fqn": "pulumi_oci.cloudbridge",
  "classes": {
   "oci:CloudBridge/inventory:Inventory": "Inventory"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudGuard/cloudGuardConfiguration",
  "fqn": "pulumi_oci.cloudguard",
  "classes": {
   "oci:CloudGuard/cloudGuardConfiguration:CloudGuardConfiguration": "CloudGuardConfiguration"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudGuard/cloudGuardDataSource",
  "fqn": "pulumi_oci.cloudguard",
  "classes": {
   "oci:CloudGuard/cloudGuardDataSource:CloudGuardDataSource": "CloudGuardDataSource"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudGuard/dataMaskRule",
  "fqn": "pulumi_oci.cloudguard",
  "classes": {
   "oci:CloudGuard/dataMaskRule:DataMaskRule": "DataMaskRule"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudGuard/detectorRecipe",
  "fqn": "pulumi_oci.cloudguard",
  "classes": {
   "oci:CloudGuard/detectorRecipe:DetectorRecipe": "DetectorRecipe"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudGuard/managedList",
  "fqn": "pulumi_oci.cloudguard",
  "classes": {
   "oci:CloudGuard/managedList:ManagedList": "ManagedList"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudGuard/responderRecipe",
  "fqn": "pulumi_oci.cloudguard",
  "classes": {
   "oci:CloudGuard/responderRecipe:ResponderRecipe": "ResponderRecipe"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudGuard/securityRecipe",
  "fqn": "pulumi_oci.cloudguard",
  "classes": {
   "oci:CloudGuard/securityRecipe:SecurityRecipe": "SecurityRecipe"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudGuard/securityZone",
  "fqn": "pulumi_oci.cloudguard",
  "classes": {
   "oci:CloudGuard/securityZone:SecurityZone": "SecurityZone"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudGuard/target",
  "fqn": "pulumi_oci.cloudguard",
  "classes": {
   "oci:CloudGuard/target:Target": "Target"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudMigrations/migration",
  "fqn": "pulumi_oci.cloudmigrations",
  "classes": {
   "oci:CloudMigrations/migration:Migration": "Migration"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudMigrations/migrationAsset",
  "fqn": "pulumi_oci.cloudmigrations",
  "classes": {
   "oci:CloudMigrations/migrationAsset:MigrationAsset": "MigrationAsset"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudMigrations/migrationPlan",
  "fqn": "pulumi_oci.cloudmigrations",
  "classes": {
   "oci:CloudMigrations/migrationPlan:MigrationPlan": "MigrationPlan"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudMigrations/replicationSchedule",
  "fqn": "pulumi_oci.cloudmigrations",
  "classes": {
   "oci:CloudMigrations/replicationSchedule:ReplicationSchedule": "ReplicationSchedule"
  }
 },
 {
  "pkg": "oci",
  "mod": "CloudMigrations/targetAsset",
  "fqn": "pulumi_oci.cloudmigrations",
  "classes": {
   "oci:CloudMigrations/targetAsset:TargetAsset": "TargetAsset"
  }
 },
 {
  "pkg": "oci",
  "mod": "ContainerEngine/addon",
  "fqn": "pulumi_oci.containerengine",
  "classes": {
   "oci:ContainerEngine/addon:Addon": "Addon"
  }
 },
 {
  "pkg": "oci",
  "mod": "ContainerEngine/cluster",
  "fqn": "pulumi_oci.containerengine",
  "classes": {
   "oci:ContainerEngine/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "oci",
  "mod": "ContainerEngine/containerInstance",
  "fqn": "pulumi_oci.containerengine",
  "classes": {
   "oci:ContainerEngine/containerInstance:ContainerInstance": "ContainerInstance"
  }
 },
 {
  "pkg": "oci",
  "mod": "ContainerEngine/nodePool",
  "fqn": "pulumi_oci.containerengine",
  "classes": {
   "oci:ContainerEngine/nodePool:NodePool": "NodePool"
  }
 },
 {
  "pkg": "oci",
  "mod": "ContainerEngine/virtualNodePool",
  "fqn": "pulumi_oci.containerengine",
  "classes": {
   "oci:ContainerEngine/virtualNodePool:VirtualNodePool": "VirtualNodePool"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/appCatalogListingResourceVersionAgreement",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/appCatalogListingResourceVersionAgreement:AppCatalogListingResourceVersionAgreement": "AppCatalogListingResourceVersionAgreement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/appCatalogSubscription",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/appCatalogSubscription:AppCatalogSubscription": "AppCatalogSubscription"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/bootVolume",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/bootVolume:BootVolume": "BootVolume"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/bootVolumeBackup",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/bootVolumeBackup:BootVolumeBackup": "BootVolumeBackup"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/captureFilter",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/captureFilter:CaptureFilter": "CaptureFilter"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/clusterNetwork",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/clusterNetwork:ClusterNetwork": "ClusterNetwork"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/computeCapacityReservation",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/computeCapacityReservation:ComputeCapacityReservation": "ComputeCapacityReservation"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/computeCluster",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/computeCluster:ComputeCluster": "ComputeCluster"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/computeImageCapabilitySchema",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/computeImageCapabilitySchema:ComputeImageCapabilitySchema": "ComputeImageCapabilitySchema"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/consoleHistory",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/consoleHistory:ConsoleHistory": "ConsoleHistory"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/cpe",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/cpe:Cpe": "Cpe"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/crossConnect",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/crossConnect:CrossConnect": "CrossConnect"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/crossConnectGroup",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/crossConnectGroup:CrossConnectGroup": "CrossConnectGroup"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/dedicatedVmHost",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/dedicatedVmHost:DedicatedVmHost": "DedicatedVmHost"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/defaultDhcpOptions",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/defaultDhcpOptions:DefaultDhcpOptions": "DefaultDhcpOptions"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/defaultRouteTable",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/defaultRouteTable:DefaultRouteTable": "DefaultRouteTable"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/defaultSecurityList",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/defaultSecurityList:DefaultSecurityList": "DefaultSecurityList"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/dhcpOptions",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/dhcpOptions:DhcpOptions": "DhcpOptions"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/drg",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/drg:Drg": "Drg"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/drgAttachment",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/drgAttachment:DrgAttachment": "DrgAttachment"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/drgAttachmentManagement",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/drgAttachmentManagement:DrgAttachmentManagement": "DrgAttachmentManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/drgAttachmentsList",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/drgAttachmentsList:DrgAttachmentsList": "DrgAttachmentsList"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/drgRouteDistribution",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/drgRouteDistribution:DrgRouteDistribution": "DrgRouteDistribution"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/drgRouteDistributionStatement",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/drgRouteDistributionStatement:DrgRouteDistributionStatement": "DrgRouteDistributionStatement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/drgRouteTable",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/drgRouteTable:DrgRouteTable": "DrgRouteTable"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/drgRouteTableRouteRule",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/drgRouteTableRouteRule:DrgRouteTableRouteRule": "DrgRouteTableRouteRule"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/image",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/image:Image": "Image"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/instance",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/instanceConfiguration",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/instanceConfiguration:InstanceConfiguration": "InstanceConfiguration"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/instanceConsoleConnection",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/instanceConsoleConnection:InstanceConsoleConnection": "InstanceConsoleConnection"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/instancePool",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/instancePool:InstancePool": "InstancePool"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/instancePoolInstance",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/instancePoolInstance:InstancePoolInstance": "InstancePoolInstance"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/internetGateway",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/internetGateway:InternetGateway": "InternetGateway"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/ipsec",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/ipsec:Ipsec": "Ipsec"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/ipsecConnectionTunnelManagement",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/ipsecConnectionTunnelManagement:IpsecConnectionTunnelManagement": "IpsecConnectionTunnelManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/ipv6",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/ipv6:Ipv6": "Ipv6"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/listingResourceVersionAgreement",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/listingResourceVersionAgreement:ListingResourceVersionAgreement": "ListingResourceVersionAgreement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/localPeeringGateway",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/localPeeringGateway:LocalPeeringGateway": "LocalPeeringGateway"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/natGateway",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/natGateway:NatGateway": "NatGateway"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/networkSecurityGroup",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/networkSecurityGroup:NetworkSecurityGroup": "NetworkSecurityGroup"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/networkSecurityGroupSecurityRule",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/networkSecurityGroupSecurityRule:NetworkSecurityGroupSecurityRule": "NetworkSecurityGroupSecurityRule"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/privateIp",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/privateIp:PrivateIp": "PrivateIp"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/publicIp",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/publicIp:PublicIp": "PublicIp"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/publicIpPool",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/publicIpPool:PublicIpPool": "PublicIpPool"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/publicIpPoolCapacity",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/publicIpPoolCapacity:PublicIpPoolCapacity": "PublicIpPoolCapacity"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/remotePeeringConnection",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/remotePeeringConnection:RemotePeeringConnection": "RemotePeeringConnection"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/routeTable",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/routeTable:RouteTable": "RouteTable"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/routeTableAttachment",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/routeTableAttachment:RouteTableAttachment": "RouteTableAttachment"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/securityList",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/securityList:SecurityList": "SecurityList"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/serviceGateway",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/serviceGateway:ServiceGateway": "ServiceGateway"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/shapeManagement",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/shapeManagement:ShapeManagement": "ShapeManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/subnet",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/subnet:Subnet": "Subnet"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/vcn",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/vcn:Vcn": "Vcn"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/virtualCircuit",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/virtualCircuit:VirtualCircuit": "VirtualCircuit"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/virtualNetwork",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/virtualNetwork:VirtualNetwork": "VirtualNetwork"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/vlan",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/vlan:Vlan": "Vlan"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/vnicAttachment",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/vnicAttachment:VnicAttachment": "VnicAttachment"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/volume",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/volume:Volume": "Volume"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/volumeAttachment",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/volumeAttachment:VolumeAttachment": "VolumeAttachment"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/volumeBackup",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/volumeBackup:VolumeBackup": "VolumeBackup"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/volumeBackupPolicy",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/volumeBackupPolicy:VolumeBackupPolicy": "VolumeBackupPolicy"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/volumeBackupPolicyAssignment",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/volumeBackupPolicyAssignment:VolumeBackupPolicyAssignment": "VolumeBackupPolicyAssignment"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/volumeGroup",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/volumeGroup:VolumeGroup": "VolumeGroup"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/volumeGroupBackup",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/volumeGroupBackup:VolumeGroupBackup": "VolumeGroupBackup"
  }
 },
 {
  "pkg": "oci",
  "mod": "Core/vtap",
  "fqn": "pulumi_oci.core",
  "classes": {
   "oci:Core/vtap:Vtap": "Vtap"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataCatalog/catalog",
  "fqn": "pulumi_oci.datacatalog",
  "classes": {
   "oci:DataCatalog/catalog:Catalog": "Catalog"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataCatalog/catalogPrivateEndpoint",
  "fqn": "pulumi_oci.datacatalog",
  "classes": {
   "oci:DataCatalog/catalogPrivateEndpoint:CatalogPrivateEndpoint": "CatalogPrivateEndpoint"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataCatalog/connection",
  "fqn": "pulumi_oci.datacatalog",
  "classes": {
   "oci:DataCatalog/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataCatalog/dataAsset",
  "fqn": "pulumi_oci.datacatalog",
  "classes": {
   "oci:DataCatalog/dataAsset:DataAsset": "DataAsset"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataCatalog/metastore",
  "fqn": "pulumi_oci.datacatalog",
  "classes": {
   "oci:DataCatalog/metastore:Metastore": "Metastore"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataFlow/application",
  "fqn": "pulumi_oci.dataflow",
  "classes": {
   "oci:DataFlow/application:Application": "Application"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataFlow/invokeRun",
  "fqn": "pulumi_oci.dataflow",
  "classes": {
   "oci:DataFlow/invokeRun:InvokeRun": "InvokeRun"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataFlow/privateEndpoint",
  "fqn": "pulumi_oci.dataflow",
  "classes": {
   "oci:DataFlow/privateEndpoint:PrivateEndpoint": "PrivateEndpoint"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataFlow/runStatement",
  "fqn": "pulumi_oci.dataflow",
  "classes": {
   "oci:DataFlow/runStatement:RunStatement": "RunStatement"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataIntegration/workspace",
  "fqn": "pulumi_oci.dataintegration",
  "classes": {
   "oci:DataIntegration/workspace:Workspace": "Workspace"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataIntegration/workspaceFolder",
  "fqn": "pulumi_oci.dataintegration",
  "classes": {
   "oci:DataIntegration/workspaceFolder:WorkspaceFolder": "WorkspaceFolder"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataIntegration/workspaceProject",
  "fqn": "pulumi_oci.dataintegration",
  "classes": {
   "oci:DataIntegration/workspaceProject:WorkspaceProject": "WorkspaceProject"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataLabellingService/dataset",
  "fqn": "pulumi_oci.datalabellingservice",
  "classes": {
   "oci:DataLabellingService/dataset:Dataset": "Dataset"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/addSdmColumns",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/addSdmColumns:AddSdmColumns": "AddSdmColumns"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/alert",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/alert:Alert": "Alert"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/auditArchiveRetrieval",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/auditArchiveRetrieval:AuditArchiveRetrieval": "AuditArchiveRetrieval"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/auditPolicy",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/auditPolicy:AuditPolicy": "AuditPolicy"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/auditProfile",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/auditProfile:AuditProfile": "AuditProfile"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/auditTrail",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/auditTrail:AuditTrail": "AuditTrail"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/compareSecurityAssessment",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/compareSecurityAssessment:CompareSecurityAssessment": "CompareSecurityAssessment"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/compareUserAssessment",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/compareUserAssessment:CompareUserAssessment": "CompareUserAssessment"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/dataSafeConfiguration",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/dataSafeConfiguration:DataSafeConfiguration": "DataSafeConfiguration"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/dataSafePrivateEndpoint",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/dataSafePrivateEndpoint:DataSafePrivateEndpoint": "DataSafePrivateEndpoint"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/discoveryJobsResult",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/discoveryJobsResult:DiscoveryJobsResult": "DiscoveryJobsResult"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/discoveryMod",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/discoveryMod:DiscoveryMod": "DiscoveryMod"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/libraryMasingFormat",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/libraryMasingFormat:LibraryMasingFormat": "LibraryMasingFormat"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/maskData",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/maskData:MaskData": "MaskData"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/maskingPoliciesApplyDifferenceToMaskingColumns",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/maskingPoliciesApplyDifferenceToMaskingColumns:MaskingPoliciesApplyDifferenceToMaskingColumns": "MaskingPoliciesApplyDifferenceToMaskingColumns"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/maskingPoliciesMaskingColumn",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/maskingPoliciesMaskingColumn:MaskingPoliciesMaskingColumn": "MaskingPoliciesMaskingColumn"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/maskingPolicy",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/maskingPolicy:MaskingPolicy": "MaskingPolicy"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/onPremConnector",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/onPremConnector:OnPremConnector": "OnPremConnector"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/reportDefinition",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/reportDefinition:ReportDefinition": "ReportDefinition"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/sdmMaskingPolicyDifference",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/sdmMaskingPolicyDifference:SdmMaskingPolicyDifference": "SdmMaskingPolicyDifference"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/securityAssessment",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/securityAssessment:SecurityAssessment": "SecurityAssessment"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/sensitiveDataModel",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/sensitiveDataModel:SensitiveDataModel": "SensitiveDataModel"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/sensitiveDataModelsApplyDiscoveryJobResults",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/sensitiveDataModelsApplyDiscoveryJobResults:SensitiveDataModelsApplyDiscoveryJobResults": "SensitiveDataModelsApplyDiscoveryJobResults"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/sensitiveDataModelsSensitiveColumn",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/sensitiveDataModelsSensitiveColumn:SensitiveDataModelsSensitiveColumn": "SensitiveDataModelsSensitiveColumn"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/sensitiveType",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/sensitiveType:SensitiveType": "SensitiveType"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/setSecurityAssessmentBaseline",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/setSecurityAssessmentBaseline:SetSecurityAssessmentBaseline": "SetSecurityAssessmentBaseline"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/setUserAssessmentBaseline",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/setUserAssessmentBaseline:SetUserAssessmentBaseline": "SetUserAssessmentBaseline"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/targetAlertPolicyAssociation",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/targetAlertPolicyAssociation:TargetAlertPolicyAssociation": "TargetAlertPolicyAssociation"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/targetDatabase",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/targetDatabase:TargetDatabase": "TargetDatabase"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/unsetSecurityAssessmentBaseline",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/unsetSecurityAssessmentBaseline:UnsetSecurityAssessmentBaseline": "UnsetSecurityAssessmentBaseline"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/unsetUserAssessmentBaseline",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/unsetUserAssessmentBaseline:UnsetUserAssessmentBaseline": "UnsetUserAssessmentBaseline"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataSafe/userAssessment",
  "fqn": "pulumi_oci.datasafe",
  "classes": {
   "oci:DataSafe/userAssessment:UserAssessment": "UserAssessment"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataScience/job",
  "fqn": "pulumi_oci.datascience",
  "classes": {
   "oci:DataScience/job:Job": "Job"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataScience/jobRun",
  "fqn": "pulumi_oci.datascience",
  "classes": {
   "oci:DataScience/jobRun:JobRun": "JobRun"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataScience/model",
  "fqn": "pulumi_oci.datascience",
  "classes": {
   "oci:DataScience/model:Model": "Model"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataScience/modelArtifactExport",
  "fqn": "pulumi_oci.datascience",
  "classes": {
   "oci:DataScience/modelArtifactExport:ModelArtifactExport": "ModelArtifactExport"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataScience/modelArtifactImport",
  "fqn": "pulumi_oci.datascience",
  "classes": {
   "oci:DataScience/modelArtifactImport:ModelArtifactImport": "ModelArtifactImport"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataScience/modelDeployment",
  "fqn": "pulumi_oci.datascience",
  "classes": {
   "oci:DataScience/modelDeployment:ModelDeployment": "ModelDeployment"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataScience/modelProvenance",
  "fqn": "pulumi_oci.datascience",
  "classes": {
   "oci:DataScience/modelProvenance:ModelProvenance": "ModelProvenance"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataScience/modelVersionSet",
  "fqn": "pulumi_oci.datascience",
  "classes": {
   "oci:DataScience/modelVersionSet:ModelVersionSet": "ModelVersionSet"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataScience/notebookSession",
  "fqn": "pulumi_oci.datascience",
  "classes": {
   "oci:DataScience/notebookSession:NotebookSession": "NotebookSession"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataScience/pipeline",
  "fqn": "pulumi_oci.datascience",
  "classes": {
   "oci:DataScience/pipeline:Pipeline": "Pipeline"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataScience/pipelineRun",
  "fqn": "pulumi_oci.datascience",
  "classes": {
   "oci:DataScience/pipelineRun:PipelineRun": "PipelineRun"
  }
 },
 {
  "pkg": "oci",
  "mod": "DataScience/project",
  "fqn": "pulumi_oci.datascience",
  "classes": {
   "oci:DataScience/project:Project": "Project"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/applicationVip",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/applicationVip:ApplicationVip": "ApplicationVip"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/autonomousContainerDatabase",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/autonomousContainerDatabase:AutonomousContainerDatabase": "AutonomousContainerDatabase"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/autonomousContainerDatabaseDataguardAssociation",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/autonomousContainerDatabaseDataguardAssociation:AutonomousContainerDatabaseDataguardAssociation": "AutonomousContainerDatabaseDataguardAssociation"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/autonomousContainerDatabaseDataguardAssociationOperation",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/autonomousContainerDatabaseDataguardAssociationOperation:AutonomousContainerDatabaseDataguardAssociationOperation": "AutonomousContainerDatabaseDataguardAssociationOperation"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/autonomousContainerDatabaseDataguardRoleChange",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/autonomousContainerDatabaseDataguardRoleChange:AutonomousContainerDatabaseDataguardRoleChange": "AutonomousContainerDatabaseDataguardRoleChange"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/autonomousDatabase",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/autonomousDatabase:AutonomousDatabase": "AutonomousDatabase"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/autonomousDatabaseBackup",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/autonomousDatabaseBackup:AutonomousDatabaseBackup": "AutonomousDatabaseBackup"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/autonomousDatabaseInstanceWalletManagement",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/autonomousDatabaseInstanceWalletManagement:AutonomousDatabaseInstanceWalletManagement": "AutonomousDatabaseInstanceWalletManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/autonomousDatabaseRegionalWalletManagement",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/autonomousDatabaseRegionalWalletManagement:AutonomousDatabaseRegionalWalletManagement": "AutonomousDatabaseRegionalWalletManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/autonomousDatabaseWallet",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/autonomousDatabaseWallet:AutonomousDatabaseWallet": "AutonomousDatabaseWallet"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/autonomousExadataInfrastructure",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/autonomousExadataInfrastructure:AutonomousExadataInfrastructure": "AutonomousExadataInfrastructure"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/autonomousVmCluster",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/autonomousVmCluster:AutonomousVmCluster": "AutonomousVmCluster"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/backup",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/backup:Backup": "Backup"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/backupCancelManagement",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/backupCancelManagement:BackupCancelManagement": "BackupCancelManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/backupDestination",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/backupDestination:BackupDestination": "BackupDestination"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/cloudAutonomousVmCluster",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/cloudAutonomousVmCluster:CloudAutonomousVmCluster": "CloudAutonomousVmCluster"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/cloudDatabaseManagement",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/cloudDatabaseManagement:CloudDatabaseManagement": "CloudDatabaseManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/cloudExadataInfrastructure",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/cloudExadataInfrastructure:CloudExadataInfrastructure": "CloudExadataInfrastructure"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/cloudVmCluster",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/cloudVmCluster:CloudVmCluster": "CloudVmCluster"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/cloudVmClusterIormConfig",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/cloudVmClusterIormConfig:CloudVmClusterIormConfig": "CloudVmClusterIormConfig"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/dataGuardAssociation",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/dataGuardAssociation:DataGuardAssociation": "DataGuardAssociation"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/database",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/database:Database": "Database"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/databaseSoftwareImage",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/databaseSoftwareImage:DatabaseSoftwareImage": "DatabaseSoftwareImage"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/databaseUpgrade",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/databaseUpgrade:DatabaseUpgrade": "DatabaseUpgrade"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/dbHome",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/dbHome:DbHome": "DbHome"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/dbNodeConsoleConnection",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/dbNodeConsoleConnection:DbNodeConsoleConnection": "DbNodeConsoleConnection"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/dbSystem",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/dbSystem:DbSystem": "DbSystem"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/dbSystemsUpgrade",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/dbSystemsUpgrade:DbSystemsUpgrade": "DbSystemsUpgrade"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/exadataInfrastructure",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/exadataInfrastructure:ExadataInfrastructure": "ExadataInfrastructure"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/exadataInfrastructureCompute",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/exadataInfrastructureCompute:ExadataInfrastructureCompute": "ExadataInfrastructureCompute"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/exadataInfrastructureStorage",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/exadataInfrastructureStorage:ExadataInfrastructureStorage": "ExadataInfrastructureStorage"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/exadataIormConfig",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/exadataIormConfig:ExadataIormConfig": "ExadataIormConfig"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/externalContainerDatabase",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/externalContainerDatabase:ExternalContainerDatabase": "ExternalContainerDatabase"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/externalContainerDatabaseManagement",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/externalContainerDatabaseManagement:ExternalContainerDatabaseManagement": "ExternalContainerDatabaseManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/externalContainerDatabasesStackMonitoring",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/externalContainerDatabasesStackMonitoring:ExternalContainerDatabasesStackMonitoring": "ExternalContainerDatabasesStackMonitoring"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/externalDatabaseConnector",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/externalDatabaseConnector:ExternalDatabaseConnector": "ExternalDatabaseConnector"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/externalNonContainerDatabase",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/externalNonContainerDatabase:ExternalNonContainerDatabase": "ExternalNonContainerDatabase"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/externalNonContainerDatabaseManagement",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/externalNonContainerDatabaseManagement:ExternalNonContainerDatabaseManagement": "ExternalNonContainerDatabaseManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/externalNonContainerDatabaseOperationsInsightsManagement",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/externalNonContainerDatabaseOperationsInsightsManagement:ExternalNonContainerDatabaseOperationsInsightsManagement": "ExternalNonContainerDatabaseOperationsInsightsManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/externalNonContainerDatabasesStackMonitoring",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/externalNonContainerDatabasesStackMonitoring:ExternalNonContainerDatabasesStackMonitoring": "ExternalNonContainerDatabasesStackMonitoring"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/externalPluggableDatabase",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/externalPluggableDatabase:ExternalPluggableDatabase": "ExternalPluggableDatabase"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/externalPluggableDatabaseManagement",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/externalPluggableDatabaseManagement:ExternalPluggableDatabaseManagement": "ExternalPluggableDatabaseManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/externalPluggableDatabaseOperationsInsightsManagement",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/externalPluggableDatabaseOperationsInsightsManagement:ExternalPluggableDatabaseOperationsInsightsManagement": "ExternalPluggableDatabaseOperationsInsightsManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/externalPluggableDatabasesStackMonitoring",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/externalPluggableDatabasesStackMonitoring:ExternalPluggableDatabasesStackMonitoring": "ExternalPluggableDatabasesStackMonitoring"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/keyStore",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/keyStore:KeyStore": "KeyStore"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/maintenanceRun",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/maintenanceRun:MaintenanceRun": "MaintenanceRun"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/pluggableDatabase",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/pluggableDatabase:PluggableDatabase": "PluggableDatabase"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/pluggableDatabaseManagementsManagement",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/pluggableDatabaseManagementsManagement:PluggableDatabaseManagementsManagement": "PluggableDatabaseManagementsManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/pluggableDatabasesLocalClone",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/pluggableDatabasesLocalClone:PluggableDatabasesLocalClone": "PluggableDatabasesLocalClone"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/pluggableDatabasesRemoteClone",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/pluggableDatabasesRemoteClone:PluggableDatabasesRemoteClone": "PluggableDatabasesRemoteClone"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/vmCluster",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/vmCluster:VmCluster": "VmCluster"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/vmClusterAddVirtualNetwork",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/vmClusterAddVirtualNetwork:VmClusterAddVirtualNetwork": "VmClusterAddVirtualNetwork"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/vmClusterNetwork",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/vmClusterNetwork:VmClusterNetwork": "VmClusterNetwork"
  }
 },
 {
  "pkg": "oci",
  "mod": "Database/vmClusterRemoveVirtualMachine",
  "fqn": "pulumi_oci.database",
  "classes": {
   "oci:Database/vmClusterRemoveVirtualMachine:VmClusterRemoveVirtualMachine": "VmClusterRemoveVirtualMachine"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseManagement/dbManagementPrivateEndpoint",
  "fqn": "pulumi_oci.databasemanagement",
  "classes": {
   "oci:DatabaseManagement/dbManagementPrivateEndpoint:DbManagementPrivateEndpoint": "DbManagementPrivateEndpoint"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseManagement/externalAsm",
  "fqn": "pulumi_oci.databasemanagement",
  "classes": {
   "oci:DatabaseManagement/externalAsm:ExternalAsm": "ExternalAsm"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseManagement/externalCluster",
  "fqn": "pulumi_oci.databasemanagement",
  "classes": {
   "oci:DatabaseManagement/externalCluster:ExternalCluster": "ExternalCluster"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseManagement/externalClusterInstance",
  "fqn": "pulumi_oci.databasemanagement",
  "classes": {
   "oci:DatabaseManagement/externalClusterInstance:ExternalClusterInstance": "ExternalClusterInstance"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseManagement/externalDbNode",
  "fqn": "pulumi_oci.databasemanagement",
  "classes": {
   "oci:DatabaseManagement/externalDbNode:ExternalDbNode": "ExternalDbNode"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseManagement/externalDbSystem",
  "fqn": "pulumi_oci.databasemanagement",
  "classes": {
   "oci:DatabaseManagement/externalDbSystem:ExternalDbSystem": "ExternalDbSystem"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseManagement/externalDbSystemConnector",
  "fqn": "pulumi_oci.databasemanagement",
  "classes": {
   "oci:DatabaseManagement/externalDbSystemConnector:ExternalDbSystemConnector": "ExternalDbSystemConnector"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseManagement/externalDbSystemDatabaseManagementsManagement",
  "fqn": "pulumi_oci.databasemanagement",
  "classes": {
   "oci:DatabaseManagement/externalDbSystemDatabaseManagementsManagement:ExternalDbSystemDatabaseManagementsManagement": "ExternalDbSystemDatabaseManagementsManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseManagement/externalDbSystemDiscovery",
  "fqn": "pulumi_oci.databasemanagement",
  "classes": {
   "oci:DatabaseManagement/externalDbSystemDiscovery:ExternalDbSystemDiscovery": "ExternalDbSystemDiscovery"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseManagement/externalListener",
  "fqn": "pulumi_oci.databasemanagement",
  "classes": {
   "oci:DatabaseManagement/externalListener:ExternalListener": "ExternalListener"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseManagement/managedDatabaseGroup",
  "fqn": "pulumi_oci.databasemanagement",
  "classes": {
   "oci:DatabaseManagement/managedDatabaseGroup:ManagedDatabaseGroup": "ManagedDatabaseGroup"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseManagement/managedDatabasesChangeDatabaseParameter",
  "fqn": "pulumi_oci.databasemanagement",
  "classes": {
   "oci:DatabaseManagement/managedDatabasesChangeDatabaseParameter:ManagedDatabasesChangeDatabaseParameter": "ManagedDatabasesChangeDatabaseParameter"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseManagement/managedDatabasesResetDatabaseParameter",
  "fqn": "pulumi_oci.databasemanagement",
  "classes": {
   "oci:DatabaseManagement/managedDatabasesResetDatabaseParameter:ManagedDatabasesResetDatabaseParameter": "ManagedDatabasesResetDatabaseParameter"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseMigration/agent",
  "fqn": "pulumi_oci.databasemigration",
  "classes": {
   "oci:DatabaseMigration/agent:Agent": "Agent"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseMigration/connection",
  "fqn": "pulumi_oci.databasemigration",
  "classes": {
   "oci:DatabaseMigration/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseMigration/job",
  "fqn": "pulumi_oci.databasemigration",
  "classes": {
   "oci:DatabaseMigration/job:Job": "Job"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseMigration/migration",
  "fqn": "pulumi_oci.databasemigration",
  "classes": {
   "oci:DatabaseMigration/migration:Migration": "Migration"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseTools/databaseToolsConnection",
  "fqn": "pulumi_oci.databasetools",
  "classes": {
   "oci:DatabaseTools/databaseToolsConnection:DatabaseToolsConnection": "DatabaseToolsConnection"
  }
 },
 {
  "pkg": "oci",
  "mod": "DatabaseTools/databaseToolsPrivateEndpoint",
  "fqn": "pulumi_oci.databasetools",
  "classes": {
   "oci:DatabaseTools/databaseToolsPrivateEndpoint:DatabaseToolsPrivateEndpoint": "DatabaseToolsPrivateEndpoint"
  }
 },
 {
  "pkg": "oci",
  "mod": "DevOps/buildPipeline",
  "fqn": "pulumi_oci.devops",
  "classes": {
   "oci:DevOps/buildPipeline:BuildPipeline": "BuildPipeline"
  }
 },
 {
  "pkg": "oci",
  "mod": "DevOps/buildPipelineStage",
  "fqn": "pulumi_oci.devops",
  "classes": {
   "oci:DevOps/buildPipelineStage:BuildPipelineStage": "BuildPipelineStage"
  }
 },
 {
  "pkg": "oci",
  "mod": "DevOps/buildRun",
  "fqn": "pulumi_oci.devops",
  "classes": {
   "oci:DevOps/buildRun:BuildRun": "BuildRun"
  }
 },
 {
  "pkg": "oci",
  "mod": "DevOps/connection",
  "fqn": "pulumi_oci.devops",
  "classes": {
   "oci:DevOps/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "oci",
  "mod": "DevOps/deployArtifact",
  "fqn": "pulumi_oci.devops",
  "classes": {
   "oci:DevOps/deployArtifact:DeployArtifact": "DeployArtifact"
  }
 },
 {
  "pkg": "oci",
  "mod": "DevOps/deployEnvironment",
  "fqn": "pulumi_oci.devops",
  "classes": {
   "oci:DevOps/deployEnvironment:DeployEnvironment": "DeployEnvironment"
  }
 },
 {
  "pkg": "oci",
  "mod": "DevOps/deployPipeline",
  "fqn": "pulumi_oci.devops",
  "classes": {
   "oci:DevOps/deployPipeline:DeployPipeline": "DeployPipeline"
  }
 },
 {
  "pkg": "oci",
  "mod": "DevOps/deployStage",
  "fqn": "pulumi_oci.devops",
  "classes": {
   "oci:DevOps/deployStage:DeployStage": "DeployStage"
  }
 },
 {
  "pkg": "oci",
  "mod": "DevOps/deployment",
  "fqn": "pulumi_oci.devops",
  "classes": {
   "oci:DevOps/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "oci",
  "mod": "DevOps/project",
  "fqn": "pulumi_oci.devops",
  "classes": {
   "oci:DevOps/project:Project": "Project"
  }
 },
 {
  "pkg": "oci",
  "mod": "DevOps/repository",
  "fqn": "pulumi_oci.devops",
  "classes": {
   "oci:DevOps/repository:Repository": "Repository"
  }
 },
 {
  "pkg": "oci",
  "mod": "DevOps/repositoryMirror",
  "fqn": "pulumi_oci.devops",
  "classes": {
   "oci:DevOps/repositoryMirror:RepositoryMirror": "RepositoryMirror"
  }
 },
 {
  "pkg": "oci",
  "mod": "DevOps/repositoryRef",
  "fqn": "pulumi_oci.devops",
  "classes": {
   "oci:DevOps/repositoryRef:RepositoryRef": "RepositoryRef"
  }
 },
 {
  "pkg": "oci",
  "mod": "DevOps/trigger",
  "fqn": "pulumi_oci.devops",
  "classes": {
   "oci:DevOps/trigger:Trigger": "Trigger"
  }
 },
 {
  "pkg": "oci",
  "mod": "DisasterRecovery/drPlan",
  "fqn": "pulumi_oci.disasterrecovery",
  "classes": {
   "oci:DisasterRecovery/drPlan:DrPlan": "DrPlan"
  }
 },
 {
  "pkg": "oci",
  "mod": "DisasterRecovery/drPlanExecution",
  "fqn": "pulumi_oci.disasterrecovery",
  "classes": {
   "oci:DisasterRecovery/drPlanExecution:DrPlanExecution": "DrPlanExecution"
  }
 },
 {
  "pkg": "oci",
  "mod": "DisasterRecovery/drProtectionGroup",
  "fqn": "pulumi_oci.disasterrecovery",
  "classes": {
   "oci:DisasterRecovery/drProtectionGroup:DrProtectionGroup": "DrProtectionGroup"
  }
 },
 {
  "pkg": "oci",
  "mod": "Dns/actionCreateZoneFromZoneFile",
  "fqn": "pulumi_oci.dns",
  "classes": {
   "oci:Dns/actionCreateZoneFromZoneFile:ActionCreateZoneFromZoneFile": "ActionCreateZoneFromZoneFile"
  }
 },
 {
  "pkg": "oci",
  "mod": "Dns/record",
  "fqn": "pulumi_oci.dns",
  "classes": {
   "oci:Dns/record:Record": "Record"
  }
 },
 {
  "pkg": "oci",
  "mod": "Dns/resolver",
  "fqn": "pulumi_oci.dns",
  "classes": {
   "oci:Dns/resolver:Resolver": "Resolver"
  }
 },
 {
  "pkg": "oci",
  "mod": "Dns/resolverEndpoint",
  "fqn": "pulumi_oci.dns",
  "classes": {
   "oci:Dns/resolverEndpoint:ResolverEndpoint": "ResolverEndpoint"
  }
 },
 {
  "pkg": "oci",
  "mod": "Dns/rrset",
  "fqn": "pulumi_oci.dns",
  "classes": {
   "oci:Dns/rrset:Rrset": "Rrset"
  }
 },
 {
  "pkg": "oci",
  "mod": "Dns/steeringPolicy",
  "fqn": "pulumi_oci.dns",
  "classes": {
   "oci:Dns/steeringPolicy:SteeringPolicy": "SteeringPolicy"
  }
 },
 {
  "pkg": "oci",
  "mod": "Dns/steeringPolicyAttachment",
  "fqn": "pulumi_oci.dns",
  "classes": {
   "oci:Dns/steeringPolicyAttachment:SteeringPolicyAttachment": "SteeringPolicyAttachment"
  }
 },
 {
  "pkg": "oci",
  "mod": "Dns/tsigKey",
  "fqn": "pulumi_oci.dns",
  "classes": {
   "oci:Dns/tsigKey:TsigKey": "TsigKey"
  }
 },
 {
  "pkg": "oci",
  "mod": "Dns/view",
  "fqn": "pulumi_oci.dns",
  "classes": {
   "oci:Dns/view:View": "View"
  }
 },
 {
  "pkg": "oci",
  "mod": "Dns/zone",
  "fqn": "pulumi_oci.dns",
  "classes": {
   "oci:Dns/zone:Zone": "Zone"
  }
 },
 {
  "pkg": "oci",
  "mod": "EmWarehouse/emWarehouse",
  "fqn": "pulumi_oci.emwarehouse",
  "classes": {
   "oci:EmWarehouse/emWarehouse:EmWarehouse": "EmWarehouse"
  }
 },
 {
  "pkg": "oci",
  "mod": "Email/dkim",
  "fqn": "pulumi_oci.email",
  "classes": {
   "oci:Email/dkim:Dkim": "Dkim"
  }
 },
 {
  "pkg": "oci",
  "mod": "Email/emailDomain",
  "fqn": "pulumi_oci.email",
  "classes": {
   "oci:Email/emailDomain:EmailDomain": "EmailDomain"
  }
 },
 {
  "pkg": "oci",
  "mod": "Email/sender",
  "fqn": "pulumi_oci.email",
  "classes": {
   "oci:Email/sender:Sender": "Sender"
  }
 },
 {
  "pkg": "oci",
  "mod": "Email/suppression",
  "fqn": "pulumi_oci.email",
  "classes": {
   "oci:Email/suppression:Suppression": "Suppression"
  }
 },
 {
  "pkg": "oci",
  "mod": "Events/rule",
  "fqn": "pulumi_oci.events",
  "classes": {
   "oci:Events/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "oci",
  "mod": "FileStorage/export",
  "fqn": "pulumi_oci.filestorage",
  "classes": {
   "oci:FileStorage/export:Export": "Export"
  }
 },
 {
  "pkg": "oci",
  "mod": "FileStorage/exportSet",
  "fqn": "pulumi_oci.filestorage",
  "classes": {
   "oci:FileStorage/exportSet:ExportSet": "ExportSet"
  }
 },
 {
  "pkg": "oci",
  "mod": "FileStorage/fileSystem",
  "fqn": "pulumi_oci.filestorage",
  "classes": {
   "oci:FileStorage/fileSystem:FileSystem": "FileSystem"
  }
 },
 {
  "pkg": "oci",
  "mod": "FileStorage/mountTarget",
  "fqn": "pulumi_oci.filestorage",
  "classes": {
   "oci:FileStorage/mountTarget:MountTarget": "MountTarget"
  }
 },
 {
  "pkg": "oci",
  "mod": "FileStorage/replication",
  "fqn": "pulumi_oci.filestorage",
  "classes": {
   "oci:FileStorage/replication:Replication": "Replication"
  }
 },
 {
  "pkg": "oci",
  "mod": "FileStorage/snapshot",
  "fqn": "pulumi_oci.filestorage",
  "classes": {
   "oci:FileStorage/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "oci",
  "mod": "Functions/application",
  "fqn": "pulumi_oci.functions",
  "classes": {
   "oci:Functions/application:Application": "Application"
  }
 },
 {
  "pkg": "oci",
  "mod": "Functions/function",
  "fqn": "pulumi_oci.functions",
  "classes": {
   "oci:Functions/function:Function": "Function"
  }
 },
 {
  "pkg": "oci",
  "mod": "Functions/invokeFunction",
  "fqn": "pulumi_oci.functions",
  "classes": {
   "oci:Functions/invokeFunction:InvokeFunction": "InvokeFunction"
  }
 },
 {
  "pkg": "oci",
  "mod": "FusionApps/fusionEnvironment",
  "fqn": "pulumi_oci.fusionapps",
  "classes": {
   "oci:FusionApps/fusionEnvironment:FusionEnvironment": "FusionEnvironment"
  }
 },
 {
  "pkg": "oci",
  "mod": "FusionApps/fusionEnvironmentAdminUser",
  "fqn": "pulumi_oci.fusionapps",
  "classes": {
   "oci:FusionApps/fusionEnvironmentAdminUser:FusionEnvironmentAdminUser": "FusionEnvironmentAdminUser"
  }
 },
 {
  "pkg": "oci",
  "mod": "FusionApps/fusionEnvironmentDataMaskingActivity",
  "fqn": "pulumi_oci.fusionapps",
  "classes": {
   "oci:FusionApps/fusionEnvironmentDataMaskingActivity:FusionEnvironmentDataMaskingActivity": "FusionEnvironmentDataMaskingActivity"
  }
 },
 {
  "pkg": "oci",
  "mod": "FusionApps/fusionEnvironmentFamily",
  "fqn": "pulumi_oci.fusionapps",
  "classes": {
   "oci:FusionApps/fusionEnvironmentFamily:FusionEnvironmentFamily": "FusionEnvironmentFamily"
  }
 },
 {
  "pkg": "oci",
  "mod": "FusionApps/fusionEnvironmentRefreshActivity",
  "fqn": "pulumi_oci.fusionapps",
  "classes": {
   "oci:FusionApps/fusionEnvironmentRefreshActivity:FusionEnvironmentRefreshActivity": "FusionEnvironmentRefreshActivity"
  }
 },
 {
  "pkg": "oci",
  "mod": "FusionApps/fusionEnvironmentServiceAttachment",
  "fqn": "pulumi_oci.fusionapps",
  "classes": {
   "oci:FusionApps/fusionEnvironmentServiceAttachment:FusionEnvironmentServiceAttachment": "FusionEnvironmentServiceAttachment"
  }
 },
 {
  "pkg": "oci",
  "mod": "GenericArtifactsContent/artifactByPath",
  "fqn": "pulumi_oci.genericartifactscontent",
  "classes": {
   "oci:GenericArtifactsContent/artifactByPath:ArtifactByPath": "ArtifactByPath"
  }
 },
 {
  "pkg": "oci",
  "mod": "GoldenGate/connection",
  "fqn": "pulumi_oci.goldengate",
  "classes": {
   "oci:GoldenGate/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "oci",
  "mod": "GoldenGate/connectionAssignment",
  "fqn": "pulumi_oci.goldengate",
  "classes": {
   "oci:GoldenGate/connectionAssignment:ConnectionAssignment": "ConnectionAssignment"
  }
 },
 {
  "pkg": "oci",
  "mod": "GoldenGate/databaseRegistration",
  "fqn": "pulumi_oci.goldengate",
  "classes": {
   "oci:GoldenGate/databaseRegistration:DatabaseRegistration": "DatabaseRegistration"
  }
 },
 {
  "pkg": "oci",
  "mod": "GoldenGate/deployment",
  "fqn": "pulumi_oci.goldengate",
  "classes": {
   "oci:GoldenGate/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "oci",
  "mod": "GoldenGate/deploymentBackup",
  "fqn": "pulumi_oci.goldengate",
  "classes": {
   "oci:GoldenGate/deploymentBackup:DeploymentBackup": "DeploymentBackup"
  }
 },
 {
  "pkg": "oci",
  "mod": "HealthChecks/httpMonitor",
  "fqn": "pulumi_oci.healthchecks",
  "classes": {
   "oci:HealthChecks/httpMonitor:HttpMonitor": "HttpMonitor"
  }
 },
 {
  "pkg": "oci",
  "mod": "HealthChecks/httpProbe",
  "fqn": "pulumi_oci.healthchecks",
  "classes": {
   "oci:HealthChecks/httpProbe:HttpProbe": "HttpProbe"
  }
 },
 {
  "pkg": "oci",
  "mod": "HealthChecks/pingMonitor",
  "fqn": "pulumi_oci.healthchecks",
  "classes": {
   "oci:HealthChecks/pingMonitor:PingMonitor": "PingMonitor"
  }
 },
 {
  "pkg": "oci",
  "mod": "HealthChecks/pingProbe",
  "fqn": "pulumi_oci.healthchecks",
  "classes": {
   "oci:HealthChecks/pingProbe:PingProbe": "PingProbe"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/apiKey",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/apiKey:ApiKey": "ApiKey"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/authToken",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/authToken:AuthToken": "AuthToken"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/authenticationPolicy",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/authenticationPolicy:AuthenticationPolicy": "AuthenticationPolicy"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/compartment",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/compartment:Compartment": "Compartment"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/customerSecretKey",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/customerSecretKey:CustomerSecretKey": "CustomerSecretKey"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/dbCredential",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/dbCredential:DbCredential": "DbCredential"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domain",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainReplicationToRegion",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainReplicationToRegion:DomainReplicationToRegion": "DomainReplicationToRegion"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsApiKey",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsApiKey:DomainsApiKey": "DomainsApiKey"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsAuthToken",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsAuthToken:DomainsAuthToken": "DomainsAuthToken"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsAuthenticationFactorSetting",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsAuthenticationFactorSetting:DomainsAuthenticationFactorSetting": "DomainsAuthenticationFactorSetting"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsCustomerSecretKey",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsCustomerSecretKey:DomainsCustomerSecretKey": "DomainsCustomerSecretKey"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsDynamicResourceGroup",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsDynamicResourceGroup:DomainsDynamicResourceGroup": "DomainsDynamicResourceGroup"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsGroup",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsGroup:DomainsGroup": "DomainsGroup"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsIdentityProvider",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsIdentityProvider:DomainsIdentityProvider": "DomainsIdentityProvider"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsKmsiSetting",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsKmsiSetting:DomainsKmsiSetting": "DomainsKmsiSetting"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsMyApiKey",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsMyApiKey:DomainsMyApiKey": "DomainsMyApiKey"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsMyAuthToken",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsMyAuthToken:DomainsMyAuthToken": "DomainsMyAuthToken"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsMyCustomerSecretKey",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsMyCustomerSecretKey:DomainsMyCustomerSecretKey": "DomainsMyCustomerSecretKey"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsMyOauth2clientCredential",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsMyOauth2clientCredential:DomainsMyOauth2clientCredential": "DomainsMyOauth2clientCredential"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsMySmtpCredential",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsMySmtpCredential:DomainsMySmtpCredential": "DomainsMySmtpCredential"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsMySupportAccount",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsMySupportAccount:DomainsMySupportAccount": "DomainsMySupportAccount"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsMyUserDbCredential",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsMyUserDbCredential:DomainsMyUserDbCredential": "DomainsMyUserDbCredential"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsOauth2clientCredential",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsOauth2clientCredential:DomainsOauth2clientCredential": "DomainsOauth2clientCredential"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsPasswordPolicy",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsPasswordPolicy:DomainsPasswordPolicy": "DomainsPasswordPolicy"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsSmtpCredential",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsSmtpCredential:DomainsSmtpCredential": "DomainsSmtpCredential"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsUser",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsUser:DomainsUser": "DomainsUser"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/domainsUserDbCredential",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/domainsUserDbCredential:DomainsUserDbCredential": "DomainsUserDbCredential"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/dynamicGroup",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/dynamicGroup:DynamicGroup": "DynamicGroup"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/group",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/group:Group": "Group"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/identityProvider",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/identityProvider:IdentityProvider": "IdentityProvider"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/idpGroupMapping",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/idpGroupMapping:IdpGroupMapping": "IdpGroupMapping"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/importStandardTagsManagement",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/importStandardTagsManagement:ImportStandardTagsManagement": "ImportStandardTagsManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/networkSource",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/networkSource:NetworkSource": "NetworkSource"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/policy",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/smtpCredential",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/smtpCredential:SmtpCredential": "SmtpCredential"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/swiftPassword",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/swiftPassword:SwiftPassword": "SwiftPassword"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/tag",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/tag:Tag": "Tag"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/tagDefault",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/tagDefault:TagDefault": "TagDefault"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/tagNamespace",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/tagNamespace:TagNamespace": "TagNamespace"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/uiPassword",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/uiPassword:UiPassword": "UiPassword"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/user",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/user:User": "User"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/userCapabilitiesManagement",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/userCapabilitiesManagement:UserCapabilitiesManagement": "UserCapabilitiesManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Identity/userGroupMembership",
  "fqn": "pulumi_oci.identity",
  "classes": {
   "oci:Identity/userGroupMembership:UserGroupMembership": "UserGroupMembership"
  }
 },
 {
  "pkg": "oci",
  "mod": "IdentityDataPlane/generatedScopedAccessToken",
  "fqn": "pulumi_oci.identitydataplane",
  "classes": {
   "oci:IdentityDataPlane/generatedScopedAccessToken:GeneratedScopedAccessToken": "GeneratedScopedAccessToken"
  }
 },
 {
  "pkg": "oci",
  "mod": "Integration/integrationInstance",
  "fqn": "pulumi_oci.integration",
  "classes": {
   "oci:Integration/integrationInstance:IntegrationInstance": "IntegrationInstance"
  }
 },
 {
  "pkg": "oci",
  "mod": "Jms/fleet",
  "fqn": "pulumi_oci.jms",
  "classes": {
   "oci:Jms/fleet:Fleet": "Fleet"
  }
 },
 {
  "pkg": "oci",
  "mod": "Kms/encryptedData",
  "fqn": "pulumi_oci.kms",
  "classes": {
   "oci:Kms/encryptedData:EncryptedData": "EncryptedData"
  }
 },
 {
  "pkg": "oci",
  "mod": "Kms/generatedKey",
  "fqn": "pulumi_oci.kms",
  "classes": {
   "oci:Kms/generatedKey:GeneratedKey": "GeneratedKey"
  }
 },
 {
  "pkg": "oci",
  "mod": "Kms/key",
  "fqn": "pulumi_oci.kms",
  "classes": {
   "oci:Kms/key:Key": "Key"
  }
 },
 {
  "pkg": "oci",
  "mod": "Kms/keyVersion",
  "fqn": "pulumi_oci.kms",
  "classes": {
   "oci:Kms/keyVersion:KeyVersion": "KeyVersion"
  }
 },
 {
  "pkg": "oci",
  "mod": "Kms/sign",
  "fqn": "pulumi_oci.kms",
  "classes": {
   "oci:Kms/sign:Sign": "Sign"
  }
 },
 {
  "pkg": "oci",
  "mod": "Kms/vault",
  "fqn": "pulumi_oci.kms",
  "classes": {
   "oci:Kms/vault:Vault": "Vault"
  }
 },
 {
  "pkg": "oci",
  "mod": "Kms/vaultVerification",
  "fqn": "pulumi_oci.kms",
  "classes": {
   "oci:Kms/vaultVerification:VaultVerification": "VaultVerification"
  }
 },
 {
  "pkg": "oci",
  "mod": "Kms/verify",
  "fqn": "pulumi_oci.kms",
  "classes": {
   "oci:Kms/verify:Verify": "Verify"
  }
 },
 {
  "pkg": "oci",
  "mod": "LicenseManager/configuration",
  "fqn": "pulumi_oci.licensemanager",
  "classes": {
   "oci:LicenseManager/configuration:Configuration": "Configuration"
  }
 },
 {
  "pkg": "oci",
  "mod": "LicenseManager/licenseRecord",
  "fqn": "pulumi_oci.licensemanager",
  "classes": {
   "oci:LicenseManager/licenseRecord:LicenseRecord": "LicenseRecord"
  }
 },
 {
  "pkg": "oci",
  "mod": "LicenseManager/productLicense",
  "fqn": "pulumi_oci.licensemanager",
  "classes": {
   "oci:LicenseManager/productLicense:ProductLicense": "ProductLicense"
  }
 },
 {
  "pkg": "oci",
  "mod": "Limits/quota",
  "fqn": "pulumi_oci.limits",
  "classes": {
   "oci:Limits/quota:Quota": "Quota"
  }
 },
 {
  "pkg": "oci",
  "mod": "LoadBalancer/backend",
  "fqn": "pulumi_oci.loadbalancer",
  "classes": {
   "oci:LoadBalancer/backend:Backend": "Backend"
  }
 },
 {
  "pkg": "oci",
  "mod": "LoadBalancer/backendSet",
  "fqn": "pulumi_oci.loadbalancer",
  "classes": {
   "oci:LoadBalancer/backendSet:BackendSet": "BackendSet"
  }
 },
 {
  "pkg": "oci",
  "mod": "LoadBalancer/certificate",
  "fqn": "pulumi_oci.loadbalancer",
  "classes": {
   "oci:LoadBalancer/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "oci",
  "mod": "LoadBalancer/hostname",
  "fqn": "pulumi_oci.loadbalancer",
  "classes": {
   "oci:LoadBalancer/hostname:Hostname": "Hostname"
  }
 },
 {
  "pkg": "oci",
  "mod": "LoadBalancer/listener",
  "fqn": "pulumi_oci.loadbalancer",
  "classes": {
   "oci:LoadBalancer/listener:Listener": "Listener"
  }
 },
 {
  "pkg": "oci",
  "mod": "LoadBalancer/loadBalancer",
  "fqn": "pulumi_oci.loadbalancer",
  "classes": {
   "oci:LoadBalancer/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "oci",
  "mod": "LoadBalancer/loadBalancerRoutingPolicy",
  "fqn": "pulumi_oci.loadbalancer",
  "classes": {
   "oci:LoadBalancer/loadBalancerRoutingPolicy:LoadBalancerRoutingPolicy": "LoadBalancerRoutingPolicy"
  }
 },
 {
  "pkg": "oci",
  "mod": "LoadBalancer/pathRouteSet",
  "fqn": "pulumi_oci.loadbalancer",
  "classes": {
   "oci:LoadBalancer/pathRouteSet:PathRouteSet": "PathRouteSet"
  }
 },
 {
  "pkg": "oci",
  "mod": "LoadBalancer/ruleSet",
  "fqn": "pulumi_oci.loadbalancer",
  "classes": {
   "oci:LoadBalancer/ruleSet:RuleSet": "RuleSet"
  }
 },
 {
  "pkg": "oci",
  "mod": "LoadBalancer/sslCipherSuite",
  "fqn": "pulumi_oci.loadbalancer",
  "classes": {
   "oci:LoadBalancer/sslCipherSuite:SslCipherSuite": "SslCipherSuite"
  }
 },
 {
  "pkg": "oci",
  "mod": "LogAnalytics/logAnalyticsEntity",
  "fqn": "pulumi_oci.loganalytics",
  "classes": {
   "oci:LogAnalytics/logAnalyticsEntity:LogAnalyticsEntity": "LogAnalyticsEntity"
  }
 },
 {
  "pkg": "oci",
  "mod": "LogAnalytics/logAnalyticsImportCustomContent",
  "fqn": "pulumi_oci.loganalytics",
  "classes": {
   "oci:LogAnalytics/logAnalyticsImportCustomContent:LogAnalyticsImportCustomContent": "LogAnalyticsImportCustomContent"
  }
 },
 {
  "pkg": "oci",
  "mod": "LogAnalytics/logAnalyticsLogGroup",
  "fqn": "pulumi_oci.loganalytics",
  "classes": {
   "oci:LogAnalytics/logAnalyticsLogGroup:LogAnalyticsLogGroup": "LogAnalyticsLogGroup"
  }
 },
 {
  "pkg": "oci",
  "mod": "LogAnalytics/logAnalyticsObjectCollectionRule",
  "fqn": "pulumi_oci.loganalytics",
  "classes": {
   "oci:LogAnalytics/logAnalyticsObjectCollectionRule:LogAnalyticsObjectCollectionRule": "LogAnalyticsObjectCollectionRule"
  }
 },
 {
  "pkg": "oci",
  "mod": "LogAnalytics/logAnalyticsPreferencesManagement",
  "fqn": "pulumi_oci.loganalytics",
  "classes": {
   "oci:LogAnalytics/logAnalyticsPreferencesManagement:LogAnalyticsPreferencesManagement": "LogAnalyticsPreferencesManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "LogAnalytics/logAnalyticsResourceCategoriesManagement",
  "fqn": "pulumi_oci.loganalytics",
  "classes": {
   "oci:LogAnalytics/logAnalyticsResourceCategoriesManagement:LogAnalyticsResourceCategoriesManagement": "LogAnalyticsResourceCategoriesManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "LogAnalytics/logAnalyticsUnprocessedDataBucketManagement",
  "fqn": "pulumi_oci.loganalytics",
  "classes": {
   "oci:LogAnalytics/logAnalyticsUnprocessedDataBucketManagement:LogAnalyticsUnprocessedDataBucketManagement": "LogAnalyticsUnprocessedDataBucketManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "LogAnalytics/namespace",
  "fqn": "pulumi_oci.loganalytics",
  "classes": {
   "oci:LogAnalytics/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "oci",
  "mod": "LogAnalytics/namespaceIngestTimeRule",
  "fqn": "pulumi_oci.loganalytics",
  "classes": {
   "oci:LogAnalytics/namespaceIngestTimeRule:NamespaceIngestTimeRule": "NamespaceIngestTimeRule"
  }
 },
 {
  "pkg": "oci",
  "mod": "LogAnalytics/namespaceIngestTimeRulesManagement",
  "fqn": "pulumi_oci.loganalytics",
  "classes": {
   "oci:LogAnalytics/namespaceIngestTimeRulesManagement:NamespaceIngestTimeRulesManagement": "NamespaceIngestTimeRulesManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "LogAnalytics/namespaceScheduledTask",
  "fqn": "pulumi_oci.loganalytics",
  "classes": {
   "oci:LogAnalytics/namespaceScheduledTask:NamespaceScheduledTask": "NamespaceScheduledTask"
  }
 },
 {
  "pkg": "oci",
  "mod": "Logging/log",
  "fqn": "pulumi_oci.logging",
  "classes": {
   "oci:Logging/log:Log": "Log"
  }
 },
 {
  "pkg": "oci",
  "mod": "Logging/logGroup",
  "fqn": "pulumi_oci.logging",
  "classes": {
   "oci:Logging/logGroup:LogGroup": "LogGroup"
  }
 },
 {
  "pkg": "oci",
  "mod": "Logging/logSavedSearch",
  "fqn": "pulumi_oci.logging",
  "classes": {
   "oci:Logging/logSavedSearch:LogSavedSearch": "LogSavedSearch"
  }
 },
 {
  "pkg": "oci",
  "mod": "Logging/unifiedAgentConfiguration",
  "fqn": "pulumi_oci.logging",
  "classes": {
   "oci:Logging/unifiedAgentConfiguration:UnifiedAgentConfiguration": "UnifiedAgentConfiguration"
  }
 },
 {
  "pkg": "oci",
  "mod": "ManagementAgent/managementAgent",
  "fqn": "pulumi_oci.managementagent",
  "classes": {
   "oci:ManagementAgent/managementAgent:ManagementAgent": "ManagementAgent"
  }
 },
 {
  "pkg": "oci",
  "mod": "ManagementAgent/managementAgentInstallKey",
  "fqn": "pulumi_oci.managementagent",
  "classes": {
   "oci:ManagementAgent/managementAgentInstallKey:ManagementAgentInstallKey": "ManagementAgentInstallKey"
  }
 },
 {
  "pkg": "oci",
  "mod": "ManagementDashboard/managementDashboardsImport",
  "fqn": "pulumi_oci.managementdashboard",
  "classes": {
   "oci:ManagementDashboard/managementDashboardsImport:ManagementDashboardsImport": "ManagementDashboardsImport"
  }
 },
 {
  "pkg": "oci",
  "mod": "Marketplace/acceptedAgreement",
  "fqn": "pulumi_oci.marketplace",
  "classes": {
   "oci:Marketplace/acceptedAgreement:AcceptedAgreement": "AcceptedAgreement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Marketplace/listingPackageAgreement",
  "fqn": "pulumi_oci.marketplace",
  "classes": {
   "oci:Marketplace/listingPackageAgreement:ListingPackageAgreement": "ListingPackageAgreement"
  }
 },
 {
  "pkg": "oci",
  "mod": "Marketplace/publication",
  "fqn": "pulumi_oci.marketplace",
  "classes": {
   "oci:Marketplace/publication:Publication": "Publication"
  }
 },
 {
  "pkg": "oci",
  "mod": "MediaServices/mediaAsset",
  "fqn": "pulumi_oci.mediaservices",
  "classes": {
   "oci:MediaServices/mediaAsset:MediaAsset": "MediaAsset"
  }
 },
 {
  "pkg": "oci",
  "mod": "MediaServices/mediaWorkflow",
  "fqn": "pulumi_oci.mediaservices",
  "classes": {
   "oci:MediaServices/mediaWorkflow:MediaWorkflow": "MediaWorkflow"
  }
 },
 {
  "pkg": "oci",
  "mod": "MediaServices/mediaWorkflowConfiguration",
  "fqn": "pulumi_oci.mediaservices",
  "classes": {
   "oci:MediaServices/mediaWorkflowConfiguration:MediaWorkflowConfiguration": "MediaWorkflowConfiguration"
  }
 },
 {
  "pkg": "oci",
  "mod": "MediaServices/mediaWorkflowJob",
  "fqn": "pulumi_oci.mediaservices",
  "classes": {
   "oci:MediaServices/mediaWorkflowJob:MediaWorkflowJob": "MediaWorkflowJob"
  }
 },
 {
  "pkg": "oci",
  "mod": "MediaServices/streamCdnConfig",
  "fqn": "pulumi_oci.mediaservices",
  "classes": {
   "oci:MediaServices/streamCdnConfig:StreamCdnConfig": "StreamCdnConfig"
  }
 },
 {
  "pkg": "oci",
  "mod": "MediaServices/streamDistributionChannel",
  "fqn": "pulumi_oci.mediaservices",
  "classes": {
   "oci:MediaServices/streamDistributionChannel:StreamDistributionChannel": "StreamDistributionChannel"
  }
 },
 {
  "pkg": "oci",
  "mod": "MediaServices/streamPackagingConfig",
  "fqn": "pulumi_oci.mediaservices",
  "classes": {
   "oci:MediaServices/streamPackagingConfig:StreamPackagingConfig": "StreamPackagingConfig"
  }
 },
 {
  "pkg": "oci",
  "mod": "MeteringComputation/customTable",
  "fqn": "pulumi_oci.meteringcomputation",
  "classes": {
   "oci:MeteringComputation/customTable:CustomTable": "CustomTable"
  }
 },
 {
  "pkg": "oci",
  "mod": "MeteringComputation/query",
  "fqn": "pulumi_oci.meteringcomputation",
  "classes": {
   "oci:MeteringComputation/query:Query": "Query"
  }
 },
 {
  "pkg": "oci",
  "mod": "MeteringComputation/schedule",
  "fqn": "pulumi_oci.meteringcomputation",
  "classes": {
   "oci:MeteringComputation/schedule:Schedule": "Schedule"
  }
 },
 {
  "pkg": "oci",
  "mod": "MeteringComputation/usage",
  "fqn": "pulumi_oci.meteringcomputation",
  "classes": {
   "oci:MeteringComputation/usage:Usage": "Usage"
  }
 },
 {
  "pkg": "oci",
  "mod": "Monitoring/alarm",
  "fqn": "pulumi_oci.monitoring",
  "classes": {
   "oci:Monitoring/alarm:Alarm": "Alarm"
  }
 },
 {
  "pkg": "oci",
  "mod": "Mysql/analyticsCluster",
  "fqn": "pulumi_oci.mysql",
  "classes": {
   "oci:Mysql/analyticsCluster:AnalyticsCluster": "AnalyticsCluster"
  }
 },
 {
  "pkg": "oci",
  "mod": "Mysql/channel",
  "fqn": "pulumi_oci.mysql",
  "classes": {
   "oci:Mysql/channel:Channel": "Channel"
  }
 },
 {
  "pkg": "oci",
  "mod": "Mysql/heatWaveCluster",
  "fqn": "pulumi_oci.mysql",
  "classes": {
   "oci:Mysql/heatWaveCluster:HeatWaveCluster": "HeatWaveCluster"
  }
 },
 {
  "pkg": "oci",
  "mod": "Mysql/mysqlBackup",
  "fqn": "pulumi_oci.mysql",
  "classes": {
   "oci:Mysql/mysqlBackup:MysqlBackup": "MysqlBackup"
  }
 },
 {
  "pkg": "oci",
  "mod": "Mysql/mysqlConfiguration",
  "fqn": "pulumi_oci.mysql",
  "classes": {
   "oci:Mysql/mysqlConfiguration:MysqlConfiguration": "MysqlConfiguration"
  }
 },
 {
  "pkg": "oci",
  "mod": "Mysql/mysqlDbSystem",
  "fqn": "pulumi_oci.mysql",
  "classes": {
   "oci:Mysql/mysqlDbSystem:MysqlDbSystem": "MysqlDbSystem"
  }
 },
 {
  "pkg": "oci",
  "mod": "Mysql/replica",
  "fqn": "pulumi_oci.mysql",
  "classes": {
   "oci:Mysql/replica:Replica": "Replica"
  }
 },
 {
  "pkg": "oci",
  "mod": "NetworkFirewall/networkFirewall",
  "fqn": "pulumi_oci.networkfirewall",
  "classes": {
   "oci:NetworkFirewall/networkFirewall:NetworkFirewall": "NetworkFirewall"
  }
 },
 {
  "pkg": "oci",
  "mod": "NetworkFirewall/networkFirewallPolicy",
  "fqn": "pulumi_oci.networkfirewall",
  "classes": {
   "oci:NetworkFirewall/networkFirewallPolicy:NetworkFirewallPolicy": "NetworkFirewallPolicy"
  }
 },
 {
  "pkg": "oci",
  "mod": "NetworkLoadBalancer/backend",
  "fqn": "pulumi_oci.networkloadbalancer",
  "classes": {
   "oci:NetworkLoadBalancer/backend:Backend": "Backend"
  }
 },
 {
  "pkg": "oci",
  "mod": "NetworkLoadBalancer/backendSet",
  "fqn": "pulumi_oci.networkloadbalancer",
  "classes": {
   "oci:NetworkLoadBalancer/backendSet:BackendSet": "BackendSet"
  }
 },
 {
  "pkg": "oci",
  "mod": "NetworkLoadBalancer/listener",
  "fqn": "pulumi_oci.networkloadbalancer",
  "classes": {
   "oci:NetworkLoadBalancer/listener:Listener": "Listener"
  }
 },
 {
  "pkg": "oci",
  "mod": "NetworkLoadBalancer/networkLoadBalancer",
  "fqn": "pulumi_oci.networkloadbalancer",
  "classes": {
   "oci:NetworkLoadBalancer/networkLoadBalancer:NetworkLoadBalancer": "NetworkLoadBalancer"
  }
 },
 {
  "pkg": "oci",
  "mod": "NetworkLoadBalancer/networkLoadBalancersBackendSetsUnified",
  "fqn": "pulumi_oci.networkloadbalancer",
  "classes": {
   "oci:NetworkLoadBalancer/networkLoadBalancersBackendSetsUnified:NetworkLoadBalancersBackendSetsUnified": "NetworkLoadBalancersBackendSetsUnified"
  }
 },
 {
  "pkg": "oci",
  "mod": "Nosql/index",
  "fqn": "pulumi_oci.nosql",
  "classes": {
   "oci:Nosql/index:Index": "Index"
  }
 },
 {
  "pkg": "oci",
  "mod": "Nosql/table",
  "fqn": "pulumi_oci.nosql",
  "classes": {
   "oci:Nosql/table:Table": "Table"
  }
 },
 {
  "pkg": "oci",
  "mod": "ObjectStorage/bucket",
  "fqn": "pulumi_oci.objectstorage",
  "classes": {
   "oci:ObjectStorage/bucket:Bucket": "Bucket"
  }
 },
 {
  "pkg": "oci",
  "mod": "ObjectStorage/namespaceMetadata",
  "fqn": "pulumi_oci.objectstorage",
  "classes": {
   "oci:ObjectStorage/namespaceMetadata:NamespaceMetadata": "NamespaceMetadata"
  }
 },
 {
  "pkg": "oci",
  "mod": "ObjectStorage/objectLifecyclePolicy",
  "fqn": "pulumi_oci.objectstorage",
  "classes": {
   "oci:ObjectStorage/objectLifecyclePolicy:ObjectLifecyclePolicy": "ObjectLifecyclePolicy"
  }
 },
 {
  "pkg": "oci",
  "mod": "ObjectStorage/preauthrequest",
  "fqn": "pulumi_oci.objectstorage",
  "classes": {
   "oci:ObjectStorage/preauthrequest:Preauthrequest": "Preauthrequest"
  }
 },
 {
  "pkg": "oci",
  "mod": "ObjectStorage/replicationPolicy",
  "fqn": "pulumi_oci.objectstorage",
  "classes": {
   "oci:ObjectStorage/replicationPolicy:ReplicationPolicy": "ReplicationPolicy"
  }
 },
 {
  "pkg": "oci",
  "mod": "ObjectStorage/storageObject",
  "fqn": "pulumi_oci.objectstorage",
  "classes": {
   "oci:ObjectStorage/storageObject:StorageObject": "StorageObject"
  }
 },
 {
  "pkg": "oci",
  "mod": "Oce/instance",
  "fqn": "pulumi_oci.oce",
  "classes": {
   "oci:Oce/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "oci",
  "mod": "Ocvp/esxiHost",
  "fqn": "pulumi_oci.ocvp",
  "classes": {
   "oci:Ocvp/esxiHost:EsxiHost": "EsxiHost"
  }
 },
 {
  "pkg": "oci",
  "mod": "Ocvp/sddc",
  "fqn": "pulumi_oci.ocvp",
  "classes": {
   "oci:Ocvp/sddc:Sddc": "Sddc"
  }
 },
 {
  "pkg": "oci",
  "mod": "Oda/odaInstance",
  "fqn": "pulumi_oci.oda",
  "classes": {
   "oci:Oda/odaInstance:OdaInstance": "OdaInstance"
  }
 },
 {
  "pkg": "oci",
  "mod": "Oda/odaPrivateEndpoint",
  "fqn": "pulumi_oci.oda",
  "classes": {
   "oci:Oda/odaPrivateEndpoint:OdaPrivateEndpoint": "OdaPrivateEndpoint"
  }
 },
 {
  "pkg": "oci",
  "mod": "Oda/odaPrivateEndpointAttachment",
  "fqn": "pulumi_oci.oda",
  "classes": {
   "oci:Oda/odaPrivateEndpointAttachment:OdaPrivateEndpointAttachment": "OdaPrivateEndpointAttachment"
  }
 },
 {
  "pkg": "oci",
  "mod": "Oda/odaPrivateEndpointScanProxy",
  "fqn": "pulumi_oci.oda",
  "classes": {
   "oci:Oda/odaPrivateEndpointScanProxy:OdaPrivateEndpointScanProxy": "OdaPrivateEndpointScanProxy"
  }
 },
 {
  "pkg": "oci",
  "mod": "Ons/notificationTopic",
  "fqn": "pulumi_oci.ons",
  "classes": {
   "oci:Ons/notificationTopic:NotificationTopic": "NotificationTopic"
  }
 },
 {
  "pkg": "oci",
  "mod": "Ons/subscription",
  "fqn": "pulumi_oci.ons",
  "classes": {
   "oci:Ons/subscription:Subscription": "Subscription"
  }
 },
 {
  "pkg": "oci",
  "mod": "Opa/opaInstance",
  "fqn": "pulumi_oci.opa",
  "classes": {
   "oci:Opa/opaInstance:OpaInstance": "OpaInstance"
  }
 },
 {
  "pkg": "oci",
  "mod": "Opensearch/cluster",
  "fqn": "pulumi_oci.opensearch",
  "classes": {
   "oci:Opensearch/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "oci",
  "mod": "OperatorAccessControl/operatorControl",
  "fqn": "pulumi_oci.operatoraccesscontrol",
  "classes": {
   "oci:OperatorAccessControl/operatorControl:OperatorControl": "OperatorControl"
  }
 },
 {
  "pkg": "oci",
  "mod": "OperatorAccessControl/operatorControlAssignment",
  "fqn": "pulumi_oci.operatoraccesscontrol",
  "classes": {
   "oci:OperatorAccessControl/operatorControlAssignment:OperatorControlAssignment": "OperatorControlAssignment"
  }
 },
 {
  "pkg": "oci",
  "mod": "Opsi/awrHub",
  "fqn": "pulumi_oci.opsi",
  "classes": {
   "oci:Opsi/awrHub:AwrHub": "AwrHub"
  }
 },
 {
  "pkg": "oci",
  "mod": "Opsi/databaseInsight",
  "fqn": "pulumi_oci.opsi",
  "classes": {
   "oci:Opsi/databaseInsight:DatabaseInsight": "DatabaseInsight"
  }
 },
 {
  "pkg": "oci",
  "mod": "Opsi/enterpriseManagerBridge",
  "fqn": "pulumi_oci.opsi",
  "classes": {
   "oci:Opsi/enterpriseManagerBridge:EnterpriseManagerBridge": "EnterpriseManagerBridge"
  }
 },
 {
  "pkg": "oci",
  "mod": "Opsi/exadataInsight",
  "fqn": "pulumi_oci.opsi",
  "classes": {
   "oci:Opsi/exadataInsight:ExadataInsight": "ExadataInsight"
  }
 },
 {
  "pkg": "oci",
  "mod": "Opsi/hostInsight",
  "fqn": "pulumi_oci.opsi",
  "classes": {
   "oci:Opsi/hostInsight:HostInsight": "HostInsight"
  }
 },
 {
  "pkg": "oci",
  "mod": "Opsi/operationsInsightsPrivateEndpoint",
  "fqn": "pulumi_oci.opsi",
  "classes": {
   "oci:Opsi/operationsInsightsPrivateEndpoint:OperationsInsightsPrivateEndpoint": "OperationsInsightsPrivateEndpoint"
  }
 },
 {
  "pkg": "oci",
  "mod": "Opsi/operationsInsightsWarehouse",
  "fqn": "pulumi_oci.opsi",
  "classes": {
   "oci:Opsi/operationsInsightsWarehouse:OperationsInsightsWarehouse": "OperationsInsightsWarehouse"
  }
 },
 {
  "pkg": "oci",
  "mod": "Opsi/operationsInsightsWarehouseDownloadWarehouseWallet",
  "fqn": "pulumi_oci.opsi",
  "classes": {
   "oci:Opsi/operationsInsightsWarehouseDownloadWarehouseWallet:OperationsInsightsWarehouseDownloadWarehouseWallet": "OperationsInsightsWarehouseDownloadWarehouseWallet"
  }
 },
 {
  "pkg": "oci",
  "mod": "Opsi/operationsInsightsWarehouseRotateWarehouseWallet",
  "fqn": "pulumi_oci.opsi",
  "classes": {
   "oci:Opsi/operationsInsightsWarehouseRotateWarehouseWallet:OperationsInsightsWarehouseRotateWarehouseWallet": "OperationsInsightsWarehouseRotateWarehouseWallet"
  }
 },
 {
  "pkg": "oci",
  "mod": "Opsi/operationsInsightsWarehouseUser",
  "fqn": "pulumi_oci.opsi",
  "classes": {
   "oci:Opsi/operationsInsightsWarehouseUser:OperationsInsightsWarehouseUser": "OperationsInsightsWarehouseUser"
  }
 },
 {
  "pkg": "oci",
  "mod": "Opsi/opsiConfiguration",
  "fqn": "pulumi_oci.opsi",
  "classes": {
   "oci:Opsi/opsiConfiguration:OpsiConfiguration": "OpsiConfiguration"
  }
 },
 {
  "pkg": "oci",
  "mod": "Optimizer/enrollmentStatus",
  "fqn": "pulumi_oci.optimizer",
  "classes": {
   "oci:Optimizer/enrollmentStatus:EnrollmentStatus": "EnrollmentStatus"
  }
 },
 {
  "pkg": "oci",
  "mod": "Optimizer/profile",
  "fqn": "pulumi_oci.optimizer",
  "classes": {
   "oci:Optimizer/profile:Profile": "Profile"
  }
 },
 {
  "pkg": "oci",
  "mod": "Optimizer/recommendation",
  "fqn": "pulumi_oci.optimizer",
  "classes": {
   "oci:Optimizer/recommendation:Recommendation": "Recommendation"
  }
 },
 {
  "pkg": "oci",
  "mod": "Optimizer/resourceAction",
  "fqn": "pulumi_oci.optimizer",
  "classes": {
   "oci:Optimizer/resourceAction:ResourceAction": "ResourceAction"
  }
 },
 {
  "pkg": "oci",
  "mod": "OsManagement/managedInstance",
  "fqn": "pulumi_oci.osmanagement",
  "classes": {
   "oci:OsManagement/managedInstance:ManagedInstance": "ManagedInstance"
  }
 },
 {
  "pkg": "oci",
  "mod": "OsManagement/managedInstanceGroup",
  "fqn": "pulumi_oci.osmanagement",
  "classes": {
   "oci:OsManagement/managedInstanceGroup:ManagedInstanceGroup": "ManagedInstanceGroup"
  }
 },
 {
  "pkg": "oci",
  "mod": "OsManagement/managedInstanceManagement",
  "fqn": "pulumi_oci.osmanagement",
  "classes": {
   "oci:OsManagement/managedInstanceManagement:ManagedInstanceManagement": "ManagedInstanceManagement"
  }
 },
 {
  "pkg": "oci",
  "mod": "OsManagement/softwareSource",
  "fqn": "pulumi_oci.osmanagement",
  "classes": {
   "oci:OsManagement/softwareSource:SoftwareSource": "SoftwareSource"
  }
 },
 {
  "pkg": "oci",
  "mod": "OspGateway/subscription",
  "fqn": "pulumi_oci.ospgateway",
  "classes": {
   "oci:OspGateway/subscription:Subscription": "Subscription"
  }
 },
 {
  "pkg": "oci",
  "mod": "Queue/queue",
  "fqn": "pulumi_oci.queue",
  "classes": {
   "oci:Queue/queue:Queue": "Queue"
  }
 },
 {
  "pkg": "oci",
  "mod": "RecoveryMod/protectedDatabase",
  "fqn": "pulumi_oci.recoverymod",
  "classes": {
   "oci:RecoveryMod/protectedDatabase:ProtectedDatabase": "ProtectedDatabase"
  }
 },
 {
  "pkg": "oci",
  "mod": "RecoveryMod/protectionPolicy",
  "fqn": "pulumi_oci.recoverymod",
  "classes": {
   "oci:RecoveryMod/protectionPolicy:ProtectionPolicy": "ProtectionPolicy"
  }
 },
 {
  "pkg": "oci",
  "mod": "RecoveryMod/recoveryServiceSubnet",
  "fqn": "pulumi_oci.recoverymod",
  "classes": {
   "oci:RecoveryMod/recoveryServiceSubnet:RecoveryServiceSubnet": "RecoveryServiceSubnet"
  }
 },
 {
  "pkg": "oci",
  "mod": "ResourceManager/privateEndpoint",
  "fqn": "pulumi_oci.resourcemanager",
  "classes": {
   "oci:ResourceManager/privateEndpoint:PrivateEndpoint": "PrivateEndpoint"
  }
 },
 {
  "pkg": "oci",
  "mod": "Sch/connector",
  "fqn": "pulumi_oci.sch",
  "classes": {
   "oci:Sch/connector:Connector": "Connector"
  }
 },
 {
  "pkg": "oci",
  "mod": "ServiceCatalog/catalog",
  "fqn": "pulumi_oci.servicecatalog",
  "classes": {
   "oci:ServiceCatalog/catalog:Catalog": "Catalog"
  }
 },
 {
  "pkg": "oci",
  "mod": "ServiceCatalog/catalogAssociation",
  "fqn": "pulumi_oci.servicecatalog",
  "classes": {
   "oci:ServiceCatalog/catalogAssociation:CatalogAssociation": "CatalogAssociation"
  }
 },
 {
  "pkg": "oci",
  "mod": "ServiceCatalog/privateApplication",
  "fqn": "pulumi_oci.servicecatalog",
  "classes": {
   "oci:ServiceCatalog/privateApplication:PrivateApplication": "PrivateApplication"
  }
 },
 {
  "pkg": "oci",
  "mod": "ServiceMesh/accessPolicy",
  "fqn": "pulumi_oci.servicemesh",
  "classes": {
   "oci:ServiceMesh/accessPolicy:AccessPolicy": "AccessPolicy"
  }
 },
 {
  "pkg": "oci",
  "mod": "ServiceMesh/ingressGateway",
  "fqn": "pulumi_oci.servicemesh",
  "classes": {
   "oci:ServiceMesh/ingressGateway:IngressGateway": "IngressGateway"
  }
 },
 {
  "pkg": "oci",
  "mod": "ServiceMesh/ingressGatewayRouteTable",
  "fqn": "pulumi_oci.servicemesh",
  "classes": {
   "oci:ServiceMesh/ingressGatewayRouteTable:IngressGatewayRouteTable": "IngressGatewayRouteTable"
  }
 },
 {
  "pkg": "oci",
  "mod": "ServiceMesh/mesh",
  "fqn": "pulumi_oci.servicemesh",
  "classes": {
   "oci:ServiceMesh/mesh:Mesh": "Mesh"
  }
 },
 {
  "pkg": "oci",
  "mod": "ServiceMesh/virtualDeployment",
  "fqn": "pulumi_oci.servicemesh",
  "classes": {
   "oci:ServiceMesh/virtualDeployment:VirtualDeployment": "VirtualDeployment"
  }
 },
 {
  "pkg": "oci",
  "mod": "ServiceMesh/virtualService",
  "fqn": "pulumi_oci.servicemesh",
  "classes": {
   "oci:ServiceMesh/virtualService:VirtualService": "VirtualService"
  }
 },
 {
  "pkg": "oci",
  "mod": "ServiceMesh/virtualServiceRouteTable",
  "fqn": "pulumi_oci.servicemesh",
  "classes": {
   "oci:ServiceMesh/virtualServiceRouteTable:VirtualServiceRouteTable": "VirtualServiceRouteTable"
  }
 },
 {
  "pkg": "oci",
  "mod": "StackMonitoring/discoveryJob",
  "fqn": "pulumi_oci.stackmonitoring",
  "classes": {
   "oci:StackMonitoring/discoveryJob:DiscoveryJob": "DiscoveryJob"
  }
 },
 {
  "pkg": "oci",
  "mod": "StackMonitoring/monitoredResource",
  "fqn": "pulumi_oci.stackmonitoring",
  "classes": {
   "oci:StackMonitoring/monitoredResource:MonitoredResource": "MonitoredResource"
  }
 },
 {
  "pkg": "oci",
  "mod": "StackMonitoring/monitoredResourcesAssociateMonitoredResource",
  "fqn": "pulumi_oci.stackmonitoring",
  "classes": {
   "oci:StackMonitoring/monitoredResourcesAssociateMonitoredResource:MonitoredResourcesAssociateMonitoredResource": "MonitoredResourcesAssociateMonitoredResource"
  }
 },
 {
  "pkg": "oci",
  "mod": "StackMonitoring/monitoredResourcesListMember",
  "fqn": "pulumi_oci.stackmonitoring",
  "classes": {
   "oci:StackMonitoring/monitoredResourcesListMember:MonitoredResourcesListMember": "MonitoredResourcesListMember"
  }
 },
 {
  "pkg": "oci",
  "mod": "StackMonitoring/monitoredResourcesSearch",
  "fqn": "pulumi_oci.stackmonitoring",
  "classes": {
   "oci:StackMonitoring/monitoredResourcesSearch:MonitoredResourcesSearch": "MonitoredResourcesSearch"
  }
 },
 {
  "pkg": "oci",
  "mod": "StackMonitoring/monitoredResourcesSearchAssociation",
  "fqn": "pulumi_oci.stackmonitoring",
  "classes": {
   "oci:StackMonitoring/monitoredResourcesSearchAssociation:MonitoredResourcesSearchAssociation": "MonitoredResourcesSearchAssociation"
  }
 },
 {
  "pkg": "oci",
  "mod": "Streaming/connectHarness",
  "fqn": "pulumi_oci.streaming",
  "classes": {
   "oci:Streaming/connectHarness:ConnectHarness": "ConnectHarness"
  }
 },
 {
  "pkg": "oci",
  "mod": "Streaming/stream",
  "fqn": "pulumi_oci.streaming",
  "classes": {
   "oci:Streaming/stream:Stream": "Stream"
  }
 },
 {
  "pkg": "oci",
  "mod": "Streaming/streamPool",
  "fqn": "pulumi_oci.streaming",
  "classes": {
   "oci:Streaming/streamPool:StreamPool": "StreamPool"
  }
 },
 {
  "pkg": "oci",
  "mod": "UsageProxy/subscriptionRedeemableUser",
  "fqn": "pulumi_oci.usageproxy",
  "classes": {
   "oci:UsageProxy/subscriptionRedeemableUser:SubscriptionRedeemableUser": "SubscriptionRedeemableUser"
  }
 },
 {
  "pkg": "oci",
  "mod": "Vault/secret",
  "fqn": "pulumi_oci.vault",
  "classes": {
   "oci:Vault/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "oci",
  "mod": "Vbs/instVbsInstance",
  "fqn": "pulumi_oci.vbs",
  "classes": {
   "oci:Vbs/instVbsInstance:InstVbsInstance": "InstVbsInstance"
  }
 },
 {
  "pkg": "oci",
  "mod": "VisualBuilder/vbInstance",
  "fqn": "pulumi_oci.visualbuilder",
  "classes": {
   "oci:VisualBuilder/vbInstance:VbInstance": "VbInstance"
  }
 },
 {
  "pkg": "oci",
  "mod": "VnMonitoring/pathAnalysi",
  "fqn": "pulumi_oci.vnmonitoring",
  "classes": {
   "oci:VnMonitoring/pathAnalysi:PathAnalysi": "PathAnalysi"
  }
 },
 {
  "pkg": "oci",
  "mod": "VnMonitoring/pathAnalyzerTest",
  "fqn": "pulumi_oci.vnmonitoring",
  "classes": {
   "oci:VnMonitoring/pathAnalyzerTest:PathAnalyzerTest": "PathAnalyzerTest"
  }
 },
 {
  "pkg": "oci",
  "mod": "VulnerabilityScanning/containerScanRecipe",
  "fqn": "pulumi_oci.vulnerabilityscanning",
  "classes": {
   "oci:VulnerabilityScanning/containerScanRecipe:ContainerScanRecipe": "ContainerScanRecipe"
  }
 },
 {
  "pkg": "oci",
  "mod": "VulnerabilityScanning/containerScanTarget",
  "fqn": "pulumi_oci.vulnerabilityscanning",
  "classes": {
   "oci:VulnerabilityScanning/containerScanTarget:ContainerScanTarget": "ContainerScanTarget"
  }
 },
 {
  "pkg": "oci",
  "mod": "VulnerabilityScanning/hostScanRecipe",
  "fqn": "pulumi_oci.vulnerabilityscanning",
  "classes": {
   "oci:VulnerabilityScanning/hostScanRecipe:HostScanRecipe": "HostScanRecipe"
  }
 },
 {
  "pkg": "oci",
  "mod": "VulnerabilityScanning/hostScanTarget",
  "fqn": "pulumi_oci.vulnerabilityscanning",
  "classes": {
   "oci:VulnerabilityScanning/hostScanTarget:HostScanTarget": "HostScanTarget"
  }
 },
 {
  "pkg": "oci",
  "mod": "Waa/appAcceleration",
  "fqn": "pulumi_oci.waa",
  "classes": {
   "oci:Waa/appAcceleration:AppAcceleration": "AppAcceleration"
  }
 },
 {
  "pkg": "oci",
  "mod": "Waa/appAccelerationPolicy",
  "fqn": "pulumi_oci.waa",
  "classes": {
   "oci:Waa/appAccelerationPolicy:AppAccelerationPolicy": "AppAccelerationPolicy"
  }
 },
 {
  "pkg": "oci",
  "mod": "Waas/addressList",
  "fqn": "pulumi_oci.waas",
  "classes": {
   "oci:Waas/addressList:AddressList": "AddressList"
  }
 },
 {
  "pkg": "oci",
  "mod": "Waas/certificate",
  "fqn": "pulumi_oci.waas",
  "classes": {
   "oci:Waas/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "oci",
  "mod": "Waas/customProtectionRule",
  "fqn": "pulumi_oci.waas",
  "classes": {
   "oci:Waas/customProtectionRule:CustomProtectionRule": "CustomProtectionRule"
  }
 },
 {
  "pkg": "oci",
  "mod": "Waas/httpRedirect",
  "fqn": "pulumi_oci.waas",
  "classes": {
   "oci:Waas/httpRedirect:HttpRedirect": "HttpRedirect"
  }
 },
 {
  "pkg": "oci",
  "mod": "Waas/policy",
  "fqn": "pulumi_oci.waas",
  "classes": {
   "oci:Waas/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "oci",
  "mod": "Waas/protectionRule",
  "fqn": "pulumi_oci.waas",
  "classes": {
   "oci:Waas/protectionRule:ProtectionRule": "ProtectionRule"
  }
 },
 {
  "pkg": "oci",
  "mod": "Waas/purgeCache",
  "fqn": "pulumi_oci.waas",
  "classes": {
   "oci:Waas/purgeCache:PurgeCache": "PurgeCache"
  }
 },
 {
  "pkg": "oci",
  "mod": "Waf/appFirewall",
  "fqn": "pulumi_oci.waf",
  "classes": {
   "oci:Waf/appFirewall:AppFirewall": "AppFirewall"
  }
 },
 {
  "pkg": "oci",
  "mod": "Waf/appFirewallPolicy",
  "fqn": "pulumi_oci.waf",
  "classes": {
   "oci:Waf/appFirewallPolicy:AppFirewallPolicy": "AppFirewallPolicy"
  }
 },
 {
  "pkg": "oci",
  "mod": "Waf/networkAddressList",
  "fqn": "pulumi_oci.waf",
  "classes": {
   "oci:Waf/networkAddressList:NetworkAddressList": "NetworkAddressList"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "oci",
  "token": "pulumi:providers:oci",
  "fqn": "pulumi_oci",
  "class": "Provider"
 }
]
"""
)
